#-----------------------------------------------------------
# PRS Analysis
#-----------------------------------------------------------
#---------------------------------------
# edu_baseline_resid_irnt
#---------------------------------------
library(data.table)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(ggpubr)

#-----------------------------------------------------------
# Get data
#-----------------------------------------------------------
# PRS
prs_cog <- read.table("/MYPATH/Cognition_savage_noUKB.totalscore",header=TRUE)
colnames(prs_cog) <- c("f_eid", "TOTALSCORE_AVG_cog", "TOTALSCORE_SUM_cog", "TOTALALLLELCT_cog")
# Burden
burden_raw <- fread("ukbb.allburden.tsv")
# phenotype file
pheno_unrel <- fread("/MYPATH/MYFILE.EUR.unrel.txt")
# merge PRS and burden
pheno_burden_raw <- merge(pheno_unrel, burden_raw, by="IID", all=FALSE)
dat_raw <- merge(pheno_burden_raw, prs_cog, by="f_eid", all=FALSE)

dat <- as.data.frame(dat)

# burden categories
burden_list <- c("ptv.gw", "ptv.pLI_intol", "ptv.pLI_tol", "missense_MPC1_0.gw", "missense_MPC1_2.gw", "missense_MPC1_3.gw", "missense_MPC1_0.pLI_intol", "missense_MPC1_2.pLI_intol", "missense_MPC1_3.pLI_intol", "missense_MPC1_0.pLI_tol", "missense_MPC1_2.pLI_tol", "missense_MPC1_3.pLI_tol", "missense_ALL.gw", "missense_ALL.pLI_intol", "missense_ALL.pLI_tol", "synonymous.gw", "synonymous.pLI_intol", "synonymous.pLI_tol")
for (i in burden_list){
dat[,paste0(i,".bin")] <- NA
dat[which(dat[,i]>0),paste0(i,".bin")] <- 1
dat[which(dat[,i]==0),paste0(i,".bin")] <- 0
dat[,paste0(i,".bin")] <- factor(dat[,paste0(i,".bin")])	
}

# create standardized PRS_cog 
dat$prs_std_cog <- scale(dat$TOTALSCORE_SUM_cog)

# create categories for PRS_cog 
dat$prs_dec_cog <- cut(dat$TOTALSCORE_SUM_cog, quantile(dat$TOTALSCORE_SUM_cog,seq(0,1,0.1)), labels = NULL, include.lowest = TRUE)
levels(dat$prs_dec_cog) <- c(1,2,3,4,5,6,7,8,9,10)

# output 
# fwrite(dat,"UKBB.PRS_codingburden_pheno.EUR.v3.csv.gz")

#-----------------------------------------------------------
# PRS for EDU
#-----------------------------------------------------------
# dat <- fread("UKBB.PRS_codingburden_pheno.EUR.v3.csv.gz")
# dat <- as.data.frame(dat)

#-------------------
# estimate effect of PRS on EDU original scale
#-------------------
str(dat)
lm.fit <- lm(edu_baseline~prs_std_cog+sex+edu_baseline_age_mean0+edu_baseline_age_mean02+edu_baseline_age_mean0_sex+edu_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=dat)
summary(lm.fit)

#-------------------
# residualize phenotype
#-------------------
irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
    	set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}

edu_baseline.lm <- lm(edu_baseline~sex+edu_baseline_age_mean0+edu_baseline_age_mean02+edu_baseline_age_mean0_sex+edu_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=dat)
dat$edu_baseline_resid[is.na(dat$edu_baseline)==FALSE] <- residuals(edu_baseline.lm)
dat$edu_baseline_resid_irnt[is.na(dat$edu_baseline)==FALSE] <- irnt(residuals(edu_baseline.lm))

dat <- dat[which(is.na(dat$edu_baseline_resid_irnt)==FALSE),]
summary(dat$edu_baseline)
sd(dat$edu_baseline, na.rm=TRUE)
summary(dat$edu_baseline_resid_irnt)
sd(dat$edu_baseline_resid_irnt, na.rm=TRUE)

#-----------------------------
# PRS and PTV carrier + missense carrier
#-----------------------------
summary(factor(dat$ptv.pLI_intol.bin))
summary(factor(dat$missense_MPC1_3.pLI_intol.bin))
summary(factor(dat$missense_MPC1_2.pLI_intol.bin))
dat$missense_damaging.pLI_intol <- dat$missense_MPC1_3.pLI_intol + dat$missense_MPC1_2.pLI_intol
summary(factor(dat$missense_damaging.pLI_intol))
dat$missense_damaging.pLI_intol.bin <- NA
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol>0)] <- 1
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol==0)] <- 0
dat$missense_damaging.pLI_intol.bin <- factor(dat$missense_damaging.pLI_intol.bin)	
summary(factor(dat$missense_damaging.pLI_intol.bin))

#-------------------
# partial R2 without interaction
#-------------------
formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit.full <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin")
lm.fit.null.prs <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit.null.ptv <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+prs_std_cog")
lm.fit.null.missense <- lm(formula, data=dat)

rsq.partial(lm.fit.full,lm.fit.null.ptv,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.prs,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.missense,adj=TRUE,type=c('sse'))

#-------------------
# test PRS burden interaction
#-------------------
formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog+ptv.pLI_intol.bin*prs_std_cog+missense_damaging.pLI_intol.bin*prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

#-------------------
# edu_baseline_resid_irnt
# PTV and missense carrier 
# compare with PRS categories top 10% 
#-------------------
dat$prs_top10_cog <- cut(dat$TOTALSCORE_SUM_cog, quantile(dat$TOTALSCORE_SUM_cog,c(0,0.9,1)), labels = NULL, include.lowest = TRUE)
levels(dat$prs_top10_cog) <- c(0,1)
summary(dat$prs_top10_cog)

dat$PRS_PTV_missense_cat8 <- NA
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 1
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 2
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 3
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 4
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 5
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 6
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 7
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 8
dat$PRS_PTV_missense_cat8 <- factor(dat$PRS_PTV_missense_cat8)

formula <- paste0("edu_baseline_resid_irnt ~ PRS_PTV_missense_cat8")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

dat$PTV_missense_cat4 <- NA
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 1
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 2
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 3
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 4
dat$PTV_missense_cat4 <- factor(dat$PTV_missense_cat4)

formula <- paste0("edu_baseline_resid_irnt ~ PTV_missense_cat4+prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

pchisq((0.11599573/0.001757293)**2,1,lower.tail=FALSE,log.p=TRUE)/log(10)

#-------------------
# Extended Data Figure 9
# ptv and missense pLI_intol carrier vs non-carrier
#-------------------
cut_prs_50 <- quantile(dat$prs_std_cog, probs=seq(0,1,0.02))
dat$prs_std_cog_percentile <- cut(dat$prs_std_cog, cut_prs_50, include.lowest = TRUE)

edu_baseline_resid_irnt.ptv0.missense0 <- with(dat[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0),], tapply(edu_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
edu_baseline_resid_irnt.ptv0.missense1 <- with(dat[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1),], tapply(edu_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
edu_baseline_resid_irnt.ptv1.missense0 <- with(dat[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0),], tapply(edu_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
edu_baseline_resid_irnt.ptv1.missense1 <- with(dat[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1),], tapply(edu_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))

output <- cbind.data.frame(c(seq(1,100,2),seq(1,100,2),seq(1,100,2),seq(1,100,2)),c(rep("1",50),rep("2",50),rep("3",50),rep("4",50)),c(edu_baseline_resid_irnt.ptv0.missense0,edu_baseline_resid_irnt.ptv0.missense1,edu_baseline_resid_irnt.ptv1.missense0,edu_baseline_resid_irnt.ptv1.missense1))
colnames(output) <- c("PRS_percentile", "PTV_burden", "Median_slope")
output$PTV_burden <- factor(output$PTV_burden)

p1 <- ggplot(output, aes(x=PRS_percentile, y=Median_slope, color=PTV_burden)) +
geom_point() +
geom_smooth(method = "lm", formula = y ~ x, se = TRUE) +
scale_color_manual(labels = c("Non-carriers of PTV and missense variants", "Non-carriers of PTV/Carriers of missense variants","Carriers of PTV/Non-carriers of missense variants","Carriers of PTV and missense variants"), values = rev(c('#ca0020','#f4a582','#92c5de','#0571b0'))) +
theme_classic() + 
theme(plot.title = element_text(hjust = 0.5,size=12), legend.title = element_blank(),  legend.position = c(0.6,0.2), legend.text = element_text(size = 10), plot.margin=margin(10,10,20,20, "pt")) + 
guides(shape = guide_legend(override.aes = list(size = 0.8))) + 
guides(color = guide_legend(override.aes = list(size = 0.8))) +
labs(y = "Median standardized, residualized educational attainment", x = "PRS quantile (2% groups)", title = "")
p1

#-----------------------------------------------------------
# PRS for VNR
#-----------------------------------------------------------
# dat <- fread("UKBB.PRS_codingburden_pheno.EUR.v3.csv.gz")
# dat <- as.data.frame(dat)

#-------------------
# residualize phenotype
#-------------------
irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
    	set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}
fiall_baseline.lm <- lm(fiall_baseline~sex+fiall_baseline_age_mean0+fiall_baseline_age_mean02+fiall_baseline_age_mean0_sex+fiall_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=dat)
dat$fiall_baseline_resid[is.na(dat$fiall_baseline)==FALSE] <- residuals(fiall_baseline.lm)
dat$fiall_baseline_resid_irnt[is.na(dat$fiall_baseline)==FALSE] <- irnt(residuals(fiall_baseline.lm))

dat <- dat[which(is.na(dat$fiall_baseline_resid_irnt)==FALSE),]
summary(dat$fiall_baseline)
sd(dat$fiall_baseline, na.rm=TRUE)
summary(dat$fiall_baseline_resid_irnt)
sd(dat$fiall_baseline_resid_irnt, na.rm=TRUE)

#-----------------------------
# PRS and PTV carrier + missense carrier
#-----------------------------
summary(factor(dat$ptv.pLI_intol.bin))
summary(factor(dat$missense_MPC1_3.pLI_intol.bin))
summary(factor(dat$missense_MPC1_2.pLI_intol.bin))
dat$missense_damaging.pLI_intol <- dat$missense_MPC1_3.pLI_intol + dat$missense_MPC1_2.pLI_intol
summary(factor(dat$missense_damaging.pLI_intol))
dat$missense_damaging.pLI_intol.bin <- NA
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol>0)] <- 1
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol==0)] <- 0
dat$missense_damaging.pLI_intol.bin <- factor(dat$missense_damaging.pLI_intol.bin)	
summary(factor(dat$missense_damaging.pLI_intol.bin))

#-------------------
# partial R2 without interaction
#-------------------
formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit.full <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin")
lm.fit.null.prs <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ missense_damaging.pLI_intol.bin+prs_std_cog")
lm.fit.null.ptv <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+prs_std_cog")
lm.fit.null.missense <- lm(formula, data=dat)

rsq.partial(lm.fit.full,lm.fit.null.ptv,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.prs,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.missense,adj=TRUE,type=c('sse'))

#-------------------
# test PRS burden interaction
#-------------------
formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_std_cog+ptv.pLI_intol.bin*prs_std_cog+missense_damaging.pLI_intol.bin*prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

#-------------------
# fiall_baseline_resid_irnt
# PTV and missense carrier 
# compare with PRS categories top 10% 
#-------------------
dat$prs_top10_cog <- cut(dat$TOTALSCORE_SUM_cog, quantile(dat$TOTALSCORE_SUM_cog,c(0,0.9,1)), labels = NULL, include.lowest = TRUE)
levels(dat$prs_top10_cog) <- c(0,1)
summary(dat$prs_top10_cog)

dat$PRS_PTV_missense_cat8 <- NA
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 1
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 2
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 3
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==0 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 4
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 5
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 6
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 7
dat$PRS_PTV_missense_cat8[which(dat$prs_top10_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 8
dat$PRS_PTV_missense_cat8 <- factor(dat$PRS_PTV_missense_cat8)

formula <- paste0("fiall_baseline_resid_irnt ~ PRS_PTV_missense_cat8")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

dat$PTV_missense_cat4 <- NA
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 1
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 2
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 3
dat$PTV_missense_cat4[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 4
dat$PTV_missense_cat4 <- factor(dat$PTV_missense_cat4)

formula <- paste0("fiall_baseline_resid_irnt ~ PTV_missense_cat4+prs_std_cog")
lm.fit <- lm(formula, data=dat)
summary(lm.fit)$coefficients

#-------------------
# Extended Data Figure 9
# ptv and missense pLI_intol carrier vs non-carrier
#-------------------
cut_prs_50 <- quantile(dat$prs_std_cog, probs=seq(0,1,0.02))
dat$prs_std_cog_percentile <- cut(dat$prs_std_cog, cut_prs_50, include.lowest = TRUE)

fiall_baseline_resid_irnt.ptv0.missense0 <- with(dat[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0),], tapply(fiall_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
fiall_baseline_resid_irnt.ptv0.missense1 <- with(dat[which(dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1),], tapply(fiall_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
fiall_baseline_resid_irnt.ptv1.missense0 <- with(dat[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0),], tapply(fiall_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))
fiall_baseline_resid_irnt.ptv1.missense1 <- with(dat[which(dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1),], tapply(fiall_baseline_resid_irnt, prs_std_cog_percentile, median, na.rm=TRUE))

output <- cbind.data.frame(c(seq(1,100,2),seq(1,100,2),seq(1,100,2),seq(1,100,2)),c(rep("1",50),rep("2",50),rep("3",50),rep("4",50)),c(fiall_baseline_resid_irnt.ptv0.missense0,fiall_baseline_resid_irnt.ptv0.missense1,fiall_baseline_resid_irnt.ptv1.missense0,fiall_baseline_resid_irnt.ptv1.missense1))
colnames(output) <- c("PRS_percentile", "PTV_burden", "Median_slope")
output$PTV_burden <- factor(output$PTV_burden)

p2 <- ggplot(output, aes(x=PRS_percentile, y=Median_slope, color=PTV_burden)) +
geom_point() +
geom_smooth(method = "lm", formula = y ~ x, se = TRUE) +
scale_color_manual(labels = c("Non-carriers of PTV and missense variants", "Non-carriers of PTVs/Carriers of missense variants","Carriers of PTVs/Non-carriers of missense variants","Carriers of PTVs and missense variants"), values = rev(c('#ca0020','#f4a582','#92c5de','#0571b0'))) +
theme_classic() + 
theme(plot.title = element_text(hjust = 0.5,size=12), legend.title = element_blank(),  legend.position = c(0.6,0.18), legend.text = element_text(size = 8), plot.margin=margin(10,10,20,20, "pt")) + 
guides(shape = guide_legend(override.aes = list(size = 0.8))) + 
guides(color = guide_legend(override.aes = list(size = 0.8))) +
labs(y = "Median standardized, residualized Verbal-numerical reasoning score", x = "PRS quantile (2% groups)", title = "")
p2

#===========================================================
# Figure 5
#===========================================================
library(data.table)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(ggpubr)
library(rsq)

#-----------------------------------------------------------
# PRS data for EDU and VNR
#-----------------------------------------------------------
# dat <- fread("UKBB.PRS_codingburden_pheno.EUR.v3.csv.gz", stringsAsFactors=FALSE, data.table=FALSE)

#-------------------
# residualize phenotype
# edu_baseline
# fiall_baseline
#-------------------
irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
    	set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}
edu_baseline.lm <- lm(edu_baseline~sex+edu_baseline_age_mean0+edu_baseline_age_mean02+edu_baseline_age_mean0_sex+edu_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=dat)
dat$edu_baseline_resid[is.na(dat$edu_baseline)==FALSE] <- residuals(edu_baseline.lm)
dat$edu_baseline_resid_irnt[is.na(dat$edu_baseline)==FALSE] <- irnt(residuals(edu_baseline.lm))
dat <- dat[which(is.na(dat$edu_baseline_resid_irnt)==FALSE),]
summary(dat$edu_baseline_resid_irnt)
sd(dat$edu_baseline_resid_irnt, na.rm=TRUE)

fiall_baseline.lm <- lm(fiall_baseline~sex+fiall_baseline_age_mean0+fiall_baseline_age_mean02+fiall_baseline_age_mean0_sex+fiall_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=dat)
dat$fiall_baseline_resid[is.na(dat$fiall_baseline)==FALSE] <- residuals(fiall_baseline.lm)
dat$fiall_baseline_resid_irnt[is.na(dat$fiall_baseline)==FALSE] <- irnt(residuals(fiall_baseline.lm))
dat <- dat[which(is.na(dat$fiall_baseline_resid_irnt)==FALSE),]
summary(dat$fiall_baseline_resid_irnt)
sd(dat$fiall_baseline_resid_irnt, na.rm=TRUE)

#-----------------------------
# PRS and PTV carrier + missense carrier
#-----------------------------
summary(factor(dat$ptv.pLI_intol.bin))
summary(factor(dat$missense_MPC1_3.pLI_intol.bin))
summary(factor(dat$missense_MPC1_2.pLI_intol.bin))
dat$missense_damaging.pLI_intol <- dat$missense_MPC1_3.pLI_intol + dat$missense_MPC1_2.pLI_intol
summary(factor(dat$missense_damaging.pLI_intol))
dat$missense_damaging.pLI_intol.bin <- NA
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol>0)] <- 1
dat$missense_damaging.pLI_intol.bin[which(dat$missense_damaging.pLI_intol==0)] <- 0
summary(factor(dat$missense_damaging.pLI_intol.bin))

#-----------------------------
# quintiles for PRS
#-----------------------------
quantile(dat$prs_std_cog, c(0.2,0.4,0.6,0.8)) 
summary(dat$prs_std_cog)

dat$prs_quant_cog <- cut(dat$prs_std_cog, breaks = c(min(dat$prs_std_cog), -0.8416622, -0.2553799, 0.2518412, 0.8428658, max(dat$prs_std_cog)), labels = c(1,2,3,4,5), include.lowest = TRUE)

#-----------------------------
# check data
#-----------------------------
summary(dat$prs_quant_cog)
summary(factor(dat$ptv.pLI_intol.bin))
summary(factor(dat$missense_damaging.pLI_intol.bin))
summary(dat$edu_baseline_resid_irnt)
summary(dat$fiall_baseline_resid_irnt)

# make categories for plot
dat$PRSquant_PTV_missense_cat20 <- NA
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==3 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 1
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==3 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 2
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==3 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 3
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==3 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 4
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 5
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==1 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 6
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 7
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==1 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 8
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==2 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 9
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==2 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 10
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==2 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 11
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==2 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 12
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==4 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 13
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==4 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 14
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==4 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 15
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==4 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 16
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==5 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==1)] <- 17
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==5 & dat$ptv.pLI_intol.bin==1 & dat$missense_damaging.pLI_intol.bin==0)] <- 18
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==5 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==1)] <- 19
dat$PRSquant_PTV_missense_cat20[which(dat$prs_quant_cog==5 & dat$ptv.pLI_intol.bin==0 & dat$missense_damaging.pLI_intol.bin==0)] <- 20
dat$PRSquant_PTV_missense_cat20 <- factor(dat$PRSquant_PTV_missense_cat20)
summary(dat$PRSquant_PTV_missense_cat20)

#-----------------------------
# fit model
# EDU
#-----------------------------
lm.prs_quant_cog.edu <- lm(edu_baseline_resid_irnt~relevel(prs_quant_cog, ref=3)+ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin, data=dat)
summary(lm.prs_quant_cog.edu)$coeff

lm.prs_quant_cog.edu.fullmodel <- lm(edu_baseline_resid_irnt~relevel(PRSquant_PTV_missense_cat20, ref=4), data=dat)
summary(lm.prs_quant_cog.edu.fullmodel)$coeff

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_quant_cog")
lm.fit.full <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin")
lm.fit.null.prs <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ missense_damaging.pLI_intol.bin+prs_quant_cog")
lm.fit.null.ptv <- lm(formula, data=dat)

formula <- paste0("edu_baseline_resid_irnt ~ ptv.pLI_intol.bin+prs_quant_cog")
lm.fit.null.missense <- lm(formula, data=dat)

rsq.partial(lm.fit.full,lm.fit.null.ptv,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.prs,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.missense,adj=TRUE,type=c('sse'))

#-----------------------------
# plot
# EDU
#-----------------------------
dat_plot <- as.data.frame(summary(lm.prs_quant_cog.edu.fullmodel)$coeff)
colnames(dat_plot) <- c("BETA","SE","t","P")
dat_plot <- dat_plot[c(2:20),c("BETA","SE","P")]
dat_plot$group <- c(1,2,3,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20)
dat_plot$group_rare <- c(4,3,2,4,3,2,1,4,3,2,1,4,3,2,1,4,3,2,1)
dat_plot$group_prs <- c(3,3,3,1,1,1,1,2,2,2,2,4,4,4,4,5,5,5,5)
dat_plot$xaxis <- c(3, 3+0.2, 3+0.4, 1, 1+0.2, 1+0.4, 1+0.6, 2, 2+0.2, 2+0.4, 2+0.6, 4, 4+0.2, 4+0.4, 4+0.6, 5, 5+0.2, 5+0.4, 5+0.6)
rownames(dat_plot) <-c()
dat_plot
str(dat_plot)
p3 <- ggplot(data=dat_plot, aes(x=xaxis,y=BETA, color=as.factor(group_rare))) +
    geom_point() +
    geom_errorbar(aes(ymin=BETA-1.96*SE, ymax=BETA+1.96*SE), width=0.1, position=position_dodge(0.9)) +
    scale_color_manual(values = rev(c('#ca0020','#f4a582','#92c5de','#0571b0')), labels = c("Non-carriers of PTV and missense variants", "Non-carriers of PTV/Carriers of missense variants", "Carriers of PTV/Non-carriers of missense variants", "Carriers of PTV and missense variants")) +
    theme_classic() +
    theme(plot.title = element_text(hjust = 0.5,size=12), legend.title = element_blank(),  legend.position = c(0.35,0.9), legend.text = element_text(size = 10), plot.margin=margin(10,10,20,20, "pt")) + 
    guides(shape = guide_legend(override.aes = list(size = 0.8))) + 
    guides(color = guide_legend(override.aes = list(size = 0.8))) +
    labs(y = "Effect on educational attainment (BETA)", x = "Cognitive function PRS quantiles", title = "") +
    scale_x_continuous(breaks=c(1.3,2.3,3.3,4.3,5.3), labels=c("0-20%","20-40%","40-60%","60-80%","80-100%")) +
    geom_vline(xintercept = c(1.8,2.8,3.8,4.8), linetype = "dashed", color="grey74") +
    geom_segment(x=3.5, xend=3.7, y=0, yend=0, color='#0571b0') +
    annotate("text", x=3.6, y=0.02, label= "Ref", color='#0571b0')
    
#-----------------------------
# fit model
# VNR
#-----------------------------
lm.prs_quant_cog.fiall <- lm(fiall_baseline_resid_irnt~relevel(prs_quant_cog, ref=3)+ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin, data=dat)
summary(lm.prs_quant_cog.fiall)$coeff

lm.prs_quant_cog.fiall.fullmodel <- lm(fiall_baseline_resid_irnt~relevel(PRSquant_PTV_missense_cat20, ref=4), data=dat)
summary(lm.prs_quant_cog.fiall.fullmodel)$coeff

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin+prs_quant_cog")
lm.fit.full <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+missense_damaging.pLI_intol.bin")
lm.fit.null.prs <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ missense_damaging.pLI_intol.bin+prs_quant_cog")
lm.fit.null.ptv <- lm(formula, data=dat)

formula <- paste0("fiall_baseline_resid_irnt ~ ptv.pLI_intol.bin+prs_quant_cog")
lm.fit.null.missense <- lm(formula, data=dat)

rsq.partial(lm.fit.full,lm.fit.null.ptv,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.prs,adj=TRUE,type=c('sse'))

rsq.partial(lm.fit.full,lm.fit.null.missense,adj=TRUE,type=c('sse'))

#-----------------------------
# plot
# VNR
#-----------------------------
dat_plot <- as.data.frame(summary(lm.prs_quant_cog.fiall.fullmodel)$coeff)
colnames(dat_plot) <- c("BETA","SE","t","P")
dat_plot <- dat_plot[c(2:20),c("BETA","SE","P")]
dat_plot$group <- c(1,2,3,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20)
dat_plot$group_rare <- c(4,3,2,4,3,2,1,4,3,2,1,4,3,2,1,4,3,2,1)
dat_plot$group_prs <- c(3,3,3,1,1,1,1,2,2,2,2,4,4,4,4,5,5,5,5)
dat_plot$xaxis <- c(3, 3+0.2, 3+0.4, 1, 1+0.2, 1+0.4, 1+0.6, 2, 2+0.2, 2+0.4, 2+0.6, 4, 4+0.2, 4+0.4, 4+0.6, 5, 5+0.2, 5+0.4, 5+0.6)
rownames(dat_plot) <-c()
dat_plot
str(dat_plot)
p4 <- ggplot(data=dat_plot, aes(x=xaxis,y=BETA, color=as.factor(group_rare))) +
    geom_point() +
    geom_errorbar(aes(ymin=BETA-1.96*SE, ymax=BETA+1.96*SE), width=0.1, position=position_dodge(0.9)) +
    scale_color_manual(values = rev(c('#ca0020','#f4a582','#92c5de','#0571b0')), labels = c("Non-carriers of PTV and missense variants", "Non-carriers of PTV/Carriers of missense variants", "Carriers of PTV/Non-carriers of missense variants", "Carriers of PTV and missense variants")) +
    theme_classic() +
    theme(plot.title = element_text(hjust = 0.5,size=12), legend.title = element_blank(),  legend.position = c(0.35,0.9), legend.text = element_text(size = 10), plot.margin=margin(10,10,20,20, "pt")) + 
    guides(shape = guide_legend(override.aes = list(size = 0.8))) + 
    guides(color = guide_legend(override.aes = list(size = 0.8))) +
    labs(y = "Effect on verbal-numerical reasoning (BETA)", x = "Cognitive function PRS quantiles", title = "") +
    scale_x_continuous(breaks=c(1.3,2.3,3.3,4.3,5.3), labels=c("0-20%","20-40%","40-60%","60-80%","80-100%")) +
    geom_vline(xintercept = c(1.8,2.8,3.8,4.8), linetype = "dashed", color="grey74") +
    geom_segment(x=3.5, xend=3.7, y=0, yend=0, color='#0571b0') +
    annotate("text", x=3.6, y=0.02, label= "Ref", color='#0571b0')
