#-----------------------------------------------------------
# BHR
#-----------------------------------------------------------
library(data.table)
library(bhr)

args = commandArgs(trailingOnly=TRUE)
# edu_baseline_irnt fiall_baseline_irnt rt_baseline_irnt
pheno1 <- args[1]
# 0.01 0.001 0.0001
maf <- args[2]
maf.n <- as.numeric(maf)

baseline_model <- read.table("/MYPATH/ms_baseline_oe5.gene_symbol.txt",header=TRUE,stringsAsFactors=FALSE,na=NA)
baseline_model <- baseline_model[,c("gene","baseline_oe1_total5","baseline_oe2_total5","baseline_oe3_total5","baseline_oe4_total5")]
baseline_model <- baseline_model[is.na(baseline_model$gene)==FALSE,]

# provided annotation file
annot <- fread("/MYPATH/UKB_regenie.qc.annotations",header=FALSE,stringsAsFactors=FALSE,data.table=FALSE)
colnames(annot)<- c("ID","GENE","ANNOT")

# pheno 1
dat_raw <- fread(paste0("/MYPATH/ukb_regenie_step2.",pheno1,".chrauto.regenie"), header=TRUE)
dat <- merge(dat_raw,annot,by="ID",all=FALSE)
dat <- dat[is.na(dat$GENE)==FALSE,]
dat <- dat[,c("GENE","ANNOT","A1FREQ","N","BETA","CHROM","GENPOS")]
dat$twopq <- 2*dat$A1FREQ*(1-dat$A1FREQ)
dat <- dat[which(dat$A1FREQ<=maf.n | dat$A1FREQ>=(1-maf.n)),]

# output data set
table <- dat[which(dat$ANNOT == "LoF_cadd0" |dat$ANNOT == "LoF_cadd20" |dat$ANNOT == "LoF_cadd30" |dat$ANNOT == "LoF_caddno"),]
sumstats = data.frame(gene = unique(table$GENE))
sumstats$variant_variances = lapply(sumstats$gene, function(x) table$twopq[table$GENE == x]) 
sumstats$betas = lapply(sumstats$gene, function(x) table$BETA[table$GENE == x]) 
names(sumstats) <- c("gene", "variant_variances", "betas")
burdenscores = sapply(sumstats$variant_variances, function(x) sum(x))
sumstats <- sumstats[abs(scale(burdenscores)) < 8,]
sumstats_info <- dat[duplicated(dat$GENE)==FALSE,c("CHROM","GENPOS","GENE")]
colnames(sumstats_info) <- c("chromosome","gene_position","gene")
sumstats_output <- merge(sumstats,sumstats_info,by="gene",all=FALSE)
sumstats_output$N <- max(dat$N)
sumstats_output_1.ptv <- sumstats_output[with(sumstats_output, order(chromosome, gene_position)),]

table <- dat[which(dat$ANNOT == "missense_cadd0" |dat$ANNOT == "missense_cadd20" |dat$ANNOT == "missense_cadd30"),]
sumstats = data.frame(gene = unique(table$GENE))
sumstats$variant_variances = lapply(sumstats$gene, function(x) table$twopq[table$GENE == x]) 
sumstats$betas = lapply(sumstats$gene, function(x) table$BETA[table$GENE == x]) 
names(sumstats) <- c("gene", "variant_variances", "betas")
burdenscores = sapply(sumstats$variant_variances, function(x) sum(x))
sumstats <- sumstats[abs(scale(burdenscores)) < 8,]
sumstats_info <- dat[duplicated(dat$GENE)==FALSE,c("CHROM","GENPOS","GENE")]
colnames(sumstats_info) <- c("chromosome","gene_position","gene")
sumstats_output <- merge(sumstats,sumstats_info,by="gene",all=FALSE)
sumstats_output$N <- max(dat$N)
sumstats_output_1.mis <- sumstats_output[with(sumstats_output, order(chromosome, gene_position)),]

genelist.ptv <- intersect(baseline_model$gene, sumstats_output_1.ptv$gene)
baseline_model.ptv <- baseline_model[which(baseline_model$gene %in% genelist.ptv),]
sumstats_output_1.ptv <- sumstats_output_1.ptv[which(sumstats_output_1.ptv$gene %in% genelist.ptv),]

genelist.mis <- intersect(baseline_model$gene, sumstats_output_1.mis$gene)
baseline_model.mis <- baseline_model[which(baseline_model$gene %in% genelist.mis),]
sumstats_output_1.mis <- sumstats_output_1.mis[which(sumstats_output_1.mis$gene %in% genelist.mis),]

# run BHR
print("PTV")
print(maf)
bhr.output.ptv <- BHR(mode = "univariate", trait1_sumstats = sumstats_output_1.ptv, annotations = list(baseline_model.ptv))
print(c(pheno1, maf, bhr.output.ptv$mixed_model$heritabilities[,"total"]))

print("missense")
print(maf)
bhr.output.mis <- BHR(mode = "univariate", trait1_sumstats = sumstats_output_1.mis, annotations = list(baseline_model.mis))
print(c(pheno1, maf, bhr.output.mis$mixed_model$heritabilities[,"total"]))

save.image(file=paste0(pheno1,"_bhr_h2g.maf",maf,".v1.RData"))

