library(data.table)
library(dplyr)

############################################################
	# gw PTV
	# gw missense
	# gw synonymous

	# pLI-intol PTV
	# pLI-intol missense MPC > 3
	# pLI-intol missense 3 > MPC > 2
	# pLI-intol other missense
	# pLI-intol synonymous

	# pLI-tol PTV
	# pLI-tol other missense
	# pLI-tol synonymous
############################################################
# load burden
filelist <- c("gw.maf00001.ptvsum", "pLI_intol.maf00001.ptvsum", "pLI_tol.maf00001.ptvsum")
burden_raw <- fread(paste0("/MYPATH/"ptvsumfilelist[1],".txt"))
for (i in 2:4){
tmpdat <- fread(paste0("/MYPATH/"ptvsumfilelist[i],".txt"))
burden_raw <- inner_join(burden_raw,tmpdat,by="eid_sample")
}

filelist <- c("gw.maf00001.MPC1_0.missensesum", "gw.maf00001.MPC1_2.missensesum", "gw.maf00001.MPC1_3.missensesum", "pLI_intol.maf00001.MPC1_0.missensesum", "pLI_intol.maf00001.MPC1_2.missensesum", "pLI_intol.maf00001.MPC1_3.missensesum", "pLI_tol.maf00001.MPC1_0.missensesum")
for (i in 1:6){
tmpdat <- fread(paste0("/MYPATH/missensesum.",filelist[i],".txt"))
burden_raw <- inner_join(burden_raw,tmpdat,by="eid_sample")
colnames(burden_raw)[length(burden_raw)] <- filelist[i]
}

filelist <- c("gw.maf00001.synonymoussum", "pLI_intol.maf00001.synonymoussum", "pLI_tol.maf00001.synonymoussum")
for (i in 1:2){
tmpdat <- fread(paste0("/MYPATH/synonymoussum.",filelist[i],".txt"))
burden_raw <- inner_join(burden_raw,tmpdat,by="eid_sample")
colnames(burden_raw)[length(burden_raw)] <- filelist[i]
}

colnames(burden_raw)[1] <- "IID"

# load pheno
pheno_unrel <- fread("/MYPATH/MYFILE.EUR.unrel.txt")
# repeat analysis for SAS and AFR
# pheno_unrel <- fread("/MYPATH/MYFILE.AFR.unrel.txt")
# pheno_unrel <- fread("/MYPATH/MYFILE.SAS.unrel.txt")

# make data for analysis
dat_raw <- inner_join(burden_raw, pheno_unrel, by="IID")

# Calculate gw missense burden
dat_raw$gw.maf00001.missense_ALL <- dat_raw$gw.maf00001.missense_MPC1_0 + dat_raw$gw.maf00001.missense_MPC1_2 + dat_raw$gw.maf00001.missense_MPC1_3

# analysis
phenolist <- c("edu_baseline","rt_baseline","fiall_baseline")
burdenlist <- c("gw.maf00001.ptvsum", "gw.maf00001.missense_ALL", "gw.maf00001.synonymoussum","pLI_intol.maf00001.ptvsum", "pLI_tol.maf00001.ptvsum", "pLI_intol.maf00001.MPC1_0.missensesum", "pLI_intol.maf00001.MPC1_2.missensesum", "pLI_intol.maf00001.MPC1_3.missensesum", "pLI_tol.maf00001.MPC1_0.missensesum", "pLI_intol.maf00001.synonymoussum", "pLI_tol.maf00001.synonymoussum")

output_final <- c()
output_raw <- c()
for (i in 1:length(phenolist)){
	for (k in 1:length(burdenlist)){
	pheno = phenolist[i]
	burden = burdenlist[k]
	pheno_tmp <- scale(dat_raw[,paste0(pheno,"_irnt")])
	formula <- paste0(paste0("pheno_tmp~",burden,"+sex+",pheno,"_age_mean0+",pheno,"_age_mean02+",pheno,"_age_mean0_sex+",pheno,"_age_mean02_sex+"),paste0("PC",seq(1,20,1),collapse="+"),"+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023")
	glm_fit_tmp <- summary(glm(formula,data=dat_raw,family="gaussian"))
	output_raw <- rbind(output_raw, c(pheno, burden, glm_fit_tmp$coef[2,c(1,2,4)], (glm_fit_tmp$df.null+1)))
}
}

colnames(output_raw) <- c("Phenotype","Burden","BETA","SE","P","N")
output_raw <- as.data.frame(output_raw)
output_raw$Phenotype <- as.character(output_raw$Phenotype)
output_raw$Burden <- as.character(output_raw$Burden)
output_raw$BETA <- as.numeric(as.character(output_raw$BETA))
output_raw$SE <- as.numeric(as.character(output_raw$SE))
output_raw$P <- as.numeric(as.character(output_raw$P))
output_raw$N <- as.numeric(as.character(output_raw$N))
output_raw$model <- rep(1,length(output_raw[,1]))

output_final <- rbind.data.frame(output_final,output_raw) 

output_raw <- c()
for (i in 1:length(phenolist)){
	for (k in 1:length(burdenlist)){

	pheno = phenolist[i]
	burden = burdenlist[k]

	pheno_tmp <- scale(dat_raw[,paste0(pheno,"_irnt")])
	formula <- paste0(paste0("pheno_tmp~",burden,"+sex+",pheno,"_age_mean0+",pheno,"_age_mean02+",pheno,"_age_mean0_sex+",pheno,"_age_mean02_sex+"),paste0("PC",seq(1,40,1),collapse="+"),"+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023")
	glm_fit_tmp <- summary(glm(formula,data=dat_raw,family="gaussian"))
	output_raw <- rbind(output_raw, c(pheno, burden, glm_fit_tmp$coef[2,c(1,2,4)], (glm_fit_tmp$df.null+1)))
}
}

colnames(output_raw) <- c("Phenotype","Burden","BETA","SE","P","N")
output_raw <- as.data.frame(output_raw)
output_raw$Phenotype <- as.character(output_raw$Phenotype)
output_raw$Burden <- as.character(output_raw$Burden)
output_raw$BETA <- as.numeric(as.character(output_raw$BETA))
output_raw$SE <- as.numeric(as.character(output_raw$SE))
output_raw$P <- as.numeric(as.character(output_raw$P))
output_raw$N <- as.numeric(as.character(output_raw$N))
output_raw$model <- rep(2,length(output_raw[,1]))

output_final <- rbind.data.frame(output_final,output_raw) 
output_final