library(data.table)
library(dplyr)
library(ggplot2)
library(ggrepel)

############################################################
# run association analysis
# gene set burden for GWAS, exome study, and DDG2P genes
# repeat for each gene set
# SCZ, BIP, MDD, COG, EDU, nonCOGPSYCH
# ASD, DD
# DDG2P
############################################################
MPC1_3.GENESET <- read.table("/MYPATH/ukbb.gw.maf00001.missensesum_MPC1_3.GENESET.txt", header=TRUE)
MPC1_2.GENESET <- read.table("/MYPATH/ukbb.gw.maf00001.missensesum_MPC1_2.GENESET.txt", header=TRUE)
MPC1_0.GENESET <- read.table("/MYPATH/ukbb.gw.maf00001.missensesum_MPC1_0.GENESET.txt", header=TRUE)
syn.GENESET    <- read.table("/MYPATH/ukbb.gw.maf00001.synonymoussum.GENESET.txt", header=TRUE)
ptv.GENESET    <- read.table("/MYPATH/ukbb.gw.maf00001.ptvsum.GENESET.txt", header=TRUE)

burdenlist <- c("MPC1_3.GENESET", "MPC1_2.GENESET", "MPC1_0.GENESET", "syn.GENESET", "ptv.GENESET")

burden_raw <- get(burdenlist[1])
colnames(burden_raw) <- c("IID",burdenlist[1])
for (i in 2:length(burdenlist)){
tmp_dat <- get(burdenlist[i])
colnames(tmp_dat) <- c("IID",burdenlist[i])
burden_raw <- merge(burden_raw, tmp_dat,by="IID",all=TRUE)
}

# load pheno
pheno_unrel <- fread("/MYPATH/MYFILE.EUR.unrel.txt")

# make data for analysis
dat_raw <- inner_join(burden_raw, pheno_unrel, by="IID")
dat_raw <- as.data.frame(dat_raw)

############################################################
# association analysis
############################################################
phenolist <- c("edu_baseline","rt_baseline","fiall_baseline")
burdenlist <- c("MPC1_3.GENESET", "MPC1_2.GENESET", "MPC1_0.GENESET", "syn.GENESET", "ptv.GENESET")

output_raw <- c()
for (i in 1:length(phenolist)){
	for (k in 1:length(burdenlist)){

	pheno = phenolist[i]
	burden = burdenlist[k]

	pheno_tmp <- scale(dat_raw[,paste0(pheno,"_irnt")])
	formula <- paste0(paste0("pheno_tmp~",burden,"+sex+",pheno,"_age_mean0+",pheno,"_age_mean02+",pheno,"_age_mean0_sex+",pheno,"_age_mean02_sex+"),paste0("PC",seq(1,20,1),collapse="+"),"+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023")
	glm_fit_tmp <- summary(glm(formula,data=dat_raw,family="gaussian"))
	output_raw <- rbind(output_raw, c(pheno, burden, glm_fit_tmp$coef[2,c(1,2,4)], (glm_fit_tmp$df.null+1)))
}
}

colnames(output_raw) <- c("Phenotype","Burden","BETA","SE","P","N")
output_raw <- as.data.frame(output_raw)
output_raw$Phenotype <- as.character(output_raw$Phenotype)
output_raw$Burden <- as.character(output_raw$Burden)
output_raw$BETA <- as.numeric(as.character(output_raw$BETA))
output_raw$SE <- as.numeric(as.character(output_raw$SE))
output_raw$P <- as.numeric(as.character(output_raw$P))
output_raw$N <- as.numeric(as.character(output_raw$N))

output_final <- rbind.data.frame(output_final,output_raw) 
write.table(output_final,"ukbb.GENESET.association.summary.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
