library(dplyr)
library(data.table)

#===========================================================
# Calculating GWAS gene burden
gwasfile <- "/MYPATH/SCZ_genes.csv"
gene_raw <- fread(gwasfile,header=TRUE,stringsAsFactors=FALSE)
sczgwas_genes <- gene_raw$Gene

gwasfile <- "/MYPATH/BIP_genes.csv"
gene_raw <- fread(gwasfile,header=TRUE,stringsAsFactors=FALSE)
bipgwas_genes <- gene_raw$Gene

gwasfile = "/MYPATH/Howard_2019_magma_269genes.csv"
gene_raw <- fread(gwasfile,header=TRUE,stringsAsFactors=FALSE)
mddgwas_genes <- gene_raw$Gene

gwasfile <- "/MYPATH/genes.Cog_GWAS_MTAG_NOeQTL.txt"
gene_raw <- read.table(gwasfile,header=TRUE,stringsAsFactors=FALSE)
coggwas_genes <- gene_raw$symbol

gwasfile <- "/MYPATH/genes.GWAS_EA_excl23andMe_ssgac_N766345_NOeQTL.txt"
gene_raw <- read.table(gwasfile,header=TRUE,stringsAsFactors=FALSE)
eagwas_genes <- gene_raw$symbol

cog_genes_broad <- c(sczgwas_genes,bipgwas_genes,coggwas_genes,eagwas_genes,mddgwas_genes)
cog_genes_broad <- unique(cog_genes_broad)

all_genes_raw <- read.table("/MYPATH/UKB_gene_pos.txt",header=TRUE,stringsAsFactors=FALSE)
all_genes <- all_genes_raw$GENE

# create non-cog gene control set
non_cog_genes_broad <- setdiff(all_genes,cog_genes_broad)

length(cog_genes_broad)
length(non_cog_genes_broad)
length(all_genes)

set.seed(0)
non_cog_genes_broad1000 <- sample(non_cog_genes_broad, size=1082, replace = FALSE, prob = NULL)
head(non_cog_genes_broad1000)
length(non_cog_genes_broad1000)

#===========================================================
# read in pLI
#===========================================================
annot_table <- read.table("/MYPATH/gnomad.v2.1.1.lof_metrics.by_gene.txt.bgz",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table$pLI_damaging <- cut(annot_table$pLI, breaks=c(0,0.9,1), include.lowest=TRUE)
levels(annot_table$pLI_damaging) <- c("low","high")
annot_table$oe_lof_upper_damaging <- cut(annot_table$oe_lof_upper, breaks=c(0,0.35,2), include.lowest=TRUE)
levels(annot_table$oe_lof_upper_damaging) <- c("high","low")
pLI_intol <- annot_table$gene[which(annot_table$pLI_damaging=="high")]
pLI_tol <- annot_table$gene[which(annot_table$pLI_damaging=="low")]

#=======================================
# Gene lists
#=======================================
length(intersect(pLI_intol, non_cog_genes_broad1000))
length(intersect(pLI_tol, non_cog_genes_broad1000))

#=======================================
# Missense burden 
#=======================================
maflist <- c("00001")
annotlist <- c("MPC1_3","MPC1_2", "MPC1_0")
pathwaylist <- c("non_cog_genes_broad1000","sczgwas_genes","bipgwas_genes","coggwas_genes","eagwas_genes","mddgwas_genes")
for (maf in maflist){
	for (annot in annotlist){
		for (pathway in pathwaylist){
			filelist <- list.files("/MYPATH")
			searchterm <- paste0("maf",maf,".",annot)
			filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE]
			filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
			filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]

			output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
			output_gw_raw <- output_raw
			output_gw_raw.count <- 0

			for (i in 1:length(filelist_burden)){
				tmpfilename <- filelist_burden[i]
				tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

				tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
				print(c("tmpdat",dim(tmpdat)))
				if (dim(tmpdat)[2] > 0){
					output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
					colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
					output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
				}
			}
			output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
			output_gw <- output_gw_raw[,c("eid_sample","burdensum")]

			write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".missensesum_",annot,".",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")

		}
	}
}


#=======================================
# Synonymous burden 
#=======================================
maflist <- c("00001")
pathwaylist <- c("non_cog_genes_broad1000","sczgwas_genes","bipgwas_genes","coggwas_genes","eagwas_genes","mddgwas_genes")
for (maf in maflist){
	for (pathway in pathwaylist){
		filelist <- list.files("/MYPATH")
		searchterm <- paste0("maf",maf)
		filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE & is.na(stringr::str_extract(filelist, "chrX"))==TRUE]
		filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
		filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]
		output_raw <- read.table(paste0("/MYPATH/","ukbb_chr22.maf00001.synonymous.tsv"), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]

		output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
		output_gw_raw <- output_raw
		output_gw_raw.count <- 0
		for (i in 1:length(filelist_burden)){
			tmpfilename <- filelist_burden[i]
			tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
				output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
			}
		}
		output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
		output_gw <- output_gw_raw[,c("eid_sample","burdensum")]

		write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".synonymoussum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
	}
}


#=======================================
# PTV burden 
#=======================================
maflist <- c("00001")
pathwaylist <- c("non_cog_genes_broad1000","sczgwas_genes","bipgwas_genes","coggwas_genes","eagwas_genes","mddgwas_genes")

for (maf in maflist){
	for (pathway in pathwaylist){
		filelist <- list.files("/MYPATH")
		searchterm <- paste0("maf",maf)
		filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE & is.na(stringr::str_extract(filelist, "chrX"))==TRUE]
		filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
		filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]
		output_raw <- read.table(paste0("/MYPATH/","ukbb_chunk1.maf00001.ptvburden.tsv"), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]

		output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
		output_gw_raw <- output_raw
		output_gw_raw.count <- 0

		for (i in 1:length(filelist_burden)){
			tmpfilename <- filelist_burden[i]
			tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
				output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
			}
		}
		output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
		output_gw <- output_gw_raw[,c("eid_sample","burdensum")]

		write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".ptvsum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")

	}
}

