library(dplyr)
library(data.table)

#===========================================================
# read in 285 DD gene set - Kaplanis et al. Nature 2020

edu_genes <- c("ADGRB2", "GIGYF1", "KDM5B", "SLC8A1", "ANKRD12", "BCAS3", "NDUFA6", "RB1CC1")

dd_genes <- c("ABL1","ADCY5","ADNP","AFF3","AGO1","AHDC1","ALG13","AMER1","ANKRD11","AP2S1","ARF1","ARHGAP35","ARID1A","ARID1B","ARID2","ASXL1","ASXL3","ATP1A3","ATP6V0A1","ATP6V1A","ATRX","AUTS2","BCL11A","BCL11B","BCOR","BRAF","BRPF1","CACNA1A","CACNA1C","CACNA1E","CACNA1G","CAMK2B","CAMK2G","CAMTA1","CASK","CBL","CDK13","CDK8","CDKL5","CHAMP1","CHD2","CHD3","CHD4","CHD7","CHD8","CLCN4","CLTC","CNKSR2","CNOT3","COG4","COL2A1","COL4A1","COL4A3BP","COL6A1","CREBBP","CSNK2A1","CSNK2B","CTBP1","CTCF","CTNNB1","DDX23","DDX3X","DEAF1","DHDDS","DLG4","DNM1","DNM1L","DNMT3A","DPF2","DSP","DYNC1H1","DYRK1A","EBF3","EEF1A2","EFTUD2","EHMT1","EP300","ERF","FBN1","FBXO11","FBXW7","FGF12","FGFR2","FGFR3","FOXG1","FOXP1","FOXP2","GABRA1","GABRB2","GABRB3","GATA3","GATAD2B","GIGYF1","GNAI1","GNAO1","GNAS","GNB1","GNB2","GRIA2","GRIN1","GRIN2A","GRIN2B","H3F3A","HDAC4","HDAC8","HECW2","HIST1H1E","HIVEP2","HK1","HNRNPD","HNRNPK","HNRNPU","HRAS","HUWE1","IQSEC2","IRF2BPL","ITPR1","KANSL1","KAT6A","KAT6B","KCNA2","KCNB1","KCND3","KCNH1","KCNK3","KCNQ2","KCNQ3","KCNT1","KDM5B","KDM5C","KDM6A","KDM6B","KIDINS220","KIF11","KIF1A","KIF5C","KLF7","KMT2A","KMT2B","KMT2C","KMT2D","KMT2E","KMT5B","KRAS","LZTR1","MAGEL2","MAP2K1","MAP3K7","MAST1","MBD5","MECP2","MED12","MED13L","MEF2C","MEIS2","MFN2","MIB1","MMGT1","MN1","MORC2","MSL2","MSL3","MTOR","MYCN","MYT1L","NAA10","NAA15","NACC1","NEXMIF","NFIA","NFIX","NOTCH1","NR2F1","NR4A2","NSD1","NSD2","ODC1","OGT","PACS1","PACS2","PBX1","PCDH19","PDHA1","PHF21A","PHF6","PHIP","PIK3CA","PIK3R1","PIK3R2","POGZ","POU3F3","PPM1D","PPP1CB","PPP2CA","PPP2R1A","PPP2R5D","PRKAR1B","PRPF8","PRR12","PSMC5","PTCH1","PTEN","PTPN11","PUF60","PURA","QRICH1","RAB14","RAC1","RAI1","RERE","RHOBTB2","RIT1","RPS6KA3","SAMD9","SATB1","SATB2","SCN1A","SCN2A","SCN8A","SET","SETBP1","SETD1A","SETD2","SETD5","SHANK3","SHOC2","SIN3A","SKI","SLC2A1","SLC35A2","SLC6A1","SMAD4","SMARCA2","SMARCA4","SMARCB1","SMC1A","SNAP25","SON","SOX10","SOX11","SOX5","SPAST","SPEN","SPTAN1","SRCAP","SRRM2","STAG2","STXBP1","SYNGAP1","SYT1","TAB2","TAF1","TAOK1","TBL1XR1","TCF20","TCF4","TCF7L2","TFE3","TLK2","TMEM106B","TRAF7","TRIO","TRIP12","TRPM3","TRRAP","U2AF2","UBE3A","UBTF","UPF1","USP7","USP9X","VAMP2","WAC","WDR26","WDR37","WDR45","YY1","ZBTB18","ZBTB20","ZC4H2","ZEB2","ZFHX4","ZMYND11","ZNF148","ZNF292")

allgene.file <- read.table("/MYPATH/UKB_gene_pos.txt",header=TRUE,stringsAsFactors=FALSE)

allgene <- allgene.file$GENE
non_dd_all <- setdiff(allgene,dd_genes)

length(non_dd_all)
length(dd_genes)
length(allgene)

#===========================================================
# REPEAT THE ANALYSIS FOR 102 ASD gene set - Satterstrom et al. Cell 2020
# asd_genes <- c("CHD8", "SCN2A", "SYNGAP1", "ADNP", "FOXP1", "POGZ", "ARID1B", "KMT5B", "DYRK1A", "SLC6A1", "GRIN2B", "PTEN", "SHANK3", "MED13L", "GIGYF1", "CHD2", "ANKRD11", "ANK2", "ASH1L", "TLK2", "DNMT3A", "DEAF1", "CTNNB1", "KDM6B", "DSCAM", "SETD5", "KCNQ3", "SRPRA", "KDM5B", "WAC", "SHANK2", "NRXN1", "TBL1XR1", "MYT1L", "BCL11A", "RORB", "RAI1", "DYNC1H1", "DPYSL2", "AP2S1", "KMT2C", "PAX5", "MKX", "GABRB3", "SIN3A", "MBD5", "MAP1A", "STXBP1", "CELF4", "PHF12", "TBR1", "PPP2R5D", "TM9SF4", "PHF21A", "PRR12", "SKI", "ASXL3", "SPAST", "SMARCC2", "TRIP12", "CREBBP", "TCF4", "CACNA1E", "GNAI1", "TCF20", "FOXP2", "NSD1", "TCF7L2", "LDB1", "EIF3G", "PHF2", "KIAA0232", "VEZF1", "GFAP", "IRF2BPL", "ZMYND8", "SATB1", "RFX3", "SCN1A", "PPP5C", "TRIM23", "TRAF7", "ELAVL3", "GRIA2", "LRRC4C", "CACNA2D3", "NUP155", "KMT2E", "NR3C2", "NACC1", "PTK7", "PPP1R9B", "GABRB2", "HDLBP", "TAOK1", "UBR1", "TEK", "KCNMA1", "CORO1A", "HECTD4", "NCOA1", "DIP2A")
 
#===========================================================
# read in pLI
#===========================================================
annot_table <- read.table("/MYPATH/gnomad.v2.1.1.lof_metrics.by_gene.txt.bgz",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table$pLI_damaging <- cut(annot_table$pLI, breaks=c(0,0.9,1), include.lowest=TRUE)
levels(annot_table$pLI_damaging) <- c("low","high")
annot_table$oe_lof_upper_damaging <- cut(annot_table$oe_lof_upper, breaks=c(0,0.35,2), include.lowest=TRUE)
levels(annot_table$oe_lof_upper_damaging) <- c("high","low")
pLI_intol <- annot_table$gene[which(annot_table$pLI_damaging=="high")]
pLI_tol <- annot_table$gene[which(annot_table$pLI_damaging=="low")]

#=======================================
# Gene lists
#=======================================
# pLI_intol
# pLI_tol
# dd_genes
# non_dd_all

length(intersect(pLI_intol, dd_genes)) 
length(intersect(pLI_intol, non_dd_all)) 
length(intersect(pLI_tol, dd_genes)) 
length(intersect(pLI_tol, non_dd_all)) 

#=======================================
# Missense burden 
#=======================================
maflist <- c("00001")
annotlist <- c("MPC1_3","MPC1_2", "MPC1_0")
pathwaylist <- c("dd_genes", "non_dd_all")

for (maf in maflist){
	for (annot in annotlist){
		for (pathway in pathwaylist){
			filelist <- list.files("/MYPATH")
			searchterm <- paste0("maf",maf,".",annot)
			filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE]
			filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
			filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]

			output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
			output_gw_raw <- output_raw
			output_gw_raw.count <- 0
			output_pLI_intol_raw <- output_raw
			output_pLI_intol_raw.count <- 0
			output_pLI_tol_raw <- output_raw
			output_pLI_tol_raw.count <- 0

			for (i in 1:length(filelist_burden)){
				tmpfilename <- filelist_burden[i]
				tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

				tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
				print(c("tmpdat",dim(tmpdat)))
				if (dim(tmpdat)[2] > 0){
					output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
					colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
					output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
				}
				tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_intol)])
				print(c("tmpdat",dim(tmpdat)))
				if (dim(tmpdat)[2] > 0){
					output_pLI_intol_raw <- cbind.data.frame(output_pLI_intol_raw, rowSums(tmpdat,na.rm=TRUE))
					colnames(output_pLI_intol_raw)[length(names(output_pLI_intol_raw))] <- tmpfilename
					output_pLI_intol_raw.count <- output_pLI_intol_raw.count + dim(tmpdat)[2]
				}
				tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_tol)])
				print(c("tmpdat",dim(tmpdat)))
				if (dim(tmpdat)[2] > 0){
					output_pLI_tol_raw <- cbind.data.frame(output_pLI_tol_raw, rowSums(tmpdat,na.rm=TRUE))
					colnames(output_pLI_tol_raw)[length(names(output_pLI_tol_raw))] <- tmpfilename
					output_pLI_tol_raw.count <- output_pLI_tol_raw.count + dim(tmpdat)[2]
				}
			}
			output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
			output_pLI_intol_raw$burdensum <- rowSums(output_pLI_intol_raw[,-which(names(output_pLI_intol_raw) %in% c("eid_sample"))])
			output_pLI_tol_raw$burdensum   <- rowSums(output_pLI_tol_raw[,-which(names(output_pLI_tol_raw) %in% c("eid_sample"))])
			output_gw <- output_gw_raw[,c("eid_sample","burdensum")]
			output_pLI_intol <- output_pLI_intol_raw[,c("eid_sample","burdensum")]
			output_pLI_tol <- output_pLI_tol_raw[,c("eid_sample","burdensum")]

			write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".missensesum_",annot,".",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
			write.table(output_pLI_intol, paste0("ukbb.pLI_intol.maf",maf,".N",output_pLI_intol_raw.count,".missensesum_",annot,".",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
			write.table(output_pLI_tol, paste0("ukbb.pLI_tol.maf",maf,".N",output_pLI_tol_raw.count,".missensesum_",annot,".",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
		}
	}
}


#=======================================
# Synonymous burden 
#=======================================
maflist <- c("00001")
pathwaylist <- c("dd_genes", "non_dd_all")

for (maf in maflist){
	for (pathway in pathwaylist){
		filelist <- list.files("/MYPATH")
		searchterm <- paste0("maf",maf)
		filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE & is.na(stringr::str_extract(filelist, "chrX"))==TRUE]
		filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
		filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]
		output_raw <- read.table(paste0("/MYPATH/","ukbb_chr22.maf00001.synonymous.tsv"), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]

		output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
		output_gw_raw <- output_raw
		output_gw_raw.count <- 0
		output_pLI_intol_raw <- output_raw
		output_pLI_intol_raw.count <- 0
		output_pLI_tol_raw <- output_raw
		output_pLI_tol_raw.count <- 0

		for (i in 1:length(filelist_burden)){
			tmpfilename <- filelist_burden[i]
			tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
				output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
			}
			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_intol)])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_pLI_intol_raw <- cbind.data.frame(output_pLI_intol_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_pLI_intol_raw)[length(names(output_pLI_intol_raw))] <- tmpfilename
				output_pLI_intol_raw.count <- output_pLI_intol_raw.count + dim(tmpdat)[2]
			}
			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_tol)])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_pLI_tol_raw <- cbind.data.frame(output_pLI_tol_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_pLI_tol_raw)[length(names(output_pLI_tol_raw))] <- tmpfilename
				output_pLI_tol_raw.count <- output_pLI_tol_raw.count + dim(tmpdat)[2]
			}
		}
		output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
		output_pLI_intol_raw$burdensum <- rowSums(output_pLI_intol_raw[,-which(names(output_pLI_intol_raw) %in% c("eid_sample"))])
		output_pLI_tol_raw$burdensum   <- rowSums(output_pLI_tol_raw[,-which(names(output_pLI_tol_raw) %in% c("eid_sample"))])
		output_gw <- output_gw_raw[,c("eid_sample","burdensum")]
		output_pLI_intol <- output_pLI_intol_raw[,c("eid_sample","burdensum")]
		output_pLI_tol <- output_pLI_tol_raw[,c("eid_sample","burdensum")]

		write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".synonymoussum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
		write.table(output_pLI_intol, paste0("ukbb.pLI_intol.maf",maf,".N",output_pLI_intol_raw.count,".synonymoussum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
		write.table(output_pLI_tol, paste0("ukbb.pLI_tol.maf",maf,".N",output_pLI_tol_raw.count,".synonymoussum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
	}
}


#=======================================
# PTV burden 
#=======================================
maflist <- c("00001")
pathwaylist <- c("dd_genes", "non_dd_all")

for (maf in maflist){
	for (pathway in pathwaylist){
		filelist <- list.files("/MYPATH")
		searchterm <- paste0("maf",maf)
		filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE & is.na(stringr::str_extract(filelist, "chrX"))==TRUE]
		filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
		filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]
		output_raw <- read.table(paste0("/MYPATH/","ukbb_chunk156.maf00001.ptvburden.tsv"), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]

		output_raw <- read.table(paste0("/MYPATH/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
		output_gw_raw <- output_raw
		output_gw_raw.count <- 0
		output_pLI_intol_raw <- output_raw
		output_pLI_intol_raw.count <- 0
		output_pLI_tol_raw <- output_raw
		output_pLI_tol_raw.count <- 0

		for (i in 1:length(filelist_burden)){
			tmpfilename <- filelist_burden[i]
			tmpdat_raw <- as.data.frame(fread(paste0("/MYPATH/",tmpfilename), header=TRUE, stringsAsFactors=FALSE))

			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway))])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
				output_gw_raw.count <- output_gw_raw.count + dim(tmpdat)[2]
			}
			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_intol)])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_pLI_intol_raw <- cbind.data.frame(output_pLI_intol_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_pLI_intol_raw)[length(names(output_pLI_intol_raw))] <- tmpfilename
				output_pLI_intol_raw.count <- output_pLI_intol_raw.count + dim(tmpdat)[2]
			}
			tmpdat <- as.matrix(tmpdat_raw[,which(names(tmpdat_raw) %in% get(pathway) & names(tmpdat_raw) %in% pLI_tol)])
			print(c("tmpdat",dim(tmpdat)))
			if (dim(tmpdat)[2] > 0){
				output_pLI_tol_raw <- cbind.data.frame(output_pLI_tol_raw, rowSums(tmpdat,na.rm=TRUE))
				colnames(output_pLI_tol_raw)[length(names(output_pLI_tol_raw))] <- tmpfilename
				output_pLI_tol_raw.count <- output_pLI_tol_raw.count + dim(tmpdat)[2]
			}
		}
		output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(output_gw_raw) %in% c("eid_sample"))])
		output_pLI_intol_raw$burdensum <- rowSums(output_pLI_intol_raw[,-which(names(output_pLI_intol_raw) %in% c("eid_sample"))])
		output_pLI_tol_raw$burdensum   <- rowSums(output_pLI_tol_raw[,-which(names(output_pLI_tol_raw) %in% c("eid_sample"))])
		output_gw <- output_gw_raw[,c("eid_sample","burdensum")]
		output_pLI_intol <- output_pLI_intol_raw[,c("eid_sample","burdensum")]
		output_pLI_tol <- output_pLI_tol_raw[,c("eid_sample","burdensum")]

		write.table(output_gw, paste0("ukbb.gw.maf",maf,".N",output_gw_raw.count,".ptvsum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
		write.table(output_pLI_intol, paste0("ukbb.pLI_intol.maf",maf,".N",output_pLI_intol_raw.count,".ptvsum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
		write.table(output_pLI_tol, paste0("ukbb.pLI_tol.maf",maf,".N",output_pLI_tol_raw.count,".ptvsum.",pathway,".txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
	}
}

