library(dplyr)
library(data.table)

annot_table <- read.table("/MYPATH/pLI_cleaned_gnomad.v2.1.1.txt",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table$pLI_damaging <- cut(annot_table$pLI, breaks=c(0,0.9,1), include.lowest=TRUE)
levels(annot_table$pLI_damaging) <- c("low","high")

pLI_intol <- annot_table$gene[which(annot_table$pLI_damaging=="high")]
pLI_tol <- annot_table$gene[which(annot_table$pLI_damaging=="low")]

maflist <- c("00001")
annotlist <- c("MPC1_3","MPC1_2", "MPC1_0")
for (maf in maflist){
  for (annot in annotlist){
    filelist <- list.files("/MYPATH/missense_456k_matrix_v3")
    searchterm <- paste0("maf",maf,".",annot)
    filelist <- filelist[is.na(stringr::str_extract(filelist, searchterm))==FALSE & is.na(stringr::str_extract(filelist, "chrX"))==TRUE]
    filelist_burden <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==TRUE]
    filelist_info <- filelist[is.na(stringr::str_extract(filelist, '\\b(info)\\b'))==FALSE]

    output_raw <- read.table(paste0("/MYPATH/missense_456k_matrix_v3/",filelist_burden[1]), header=TRUE, stringsAsFactors=FALSE)["eid_sample"]
    output_gw_raw <- output_raw
    output_pLI_intol_raw <- output_raw
    output_pLI_tol_raw <- output_raw
    output_gw_raw.count <- 0
    output_pLI_intol_raw.count <- 0
    output_pLI_tol_raw.count <- 0
    for (i in 1:length(filelist_burden)){
      tmpfilename <- filelist_burden[i]
      tmpdat <- fread(paste0("/MYPATH/missense_456k_matrix_v3/",tmpfilename), header=TRUE, stringsAsFactors=FALSE,data.table=FALSE)

      tmpdat_gw <- as.matrix(tmpdat[,-which(names(tmpdat) %in% c("eid_sample"))])
      print(c("tmpdat_gw",dim(tmpdat_gw)))
      output_gw_raw <- cbind.data.frame(output_gw_raw, rowSums(tmpdat_gw,na.rm=TRUE))
      colnames(output_gw_raw)[length(names(output_gw_raw))] <- tmpfilename
      output_gw_raw.count <- output_gw_raw.count + dim(tmpdat_gw)[2]

      tmpdat_pLI_intol <- as.matrix(tmpdat[,which(names(tmpdat) %in% pLI_intol)])
      print(c("tmpdat_pLI_intol",dim(tmpdat_pLI_intol)))
      output_pLI_intol_raw <- cbind.data.frame(output_pLI_intol_raw, rowSums(tmpdat_pLI_intol,na.rm=TRUE))
      colnames(output_pLI_intol_raw)[length(names(output_pLI_intol_raw))] <- tmpfilename
      output_pLI_intol_raw.count <- output_pLI_intol_raw.count + dim(tmpdat_pLI_intol)[2]

      tmpdat_pLI_tol <- as.matrix(tmpdat[,which(names(tmpdat) %in% pLI_tol)])
      print(c("tmpdat_pLI_tol",dim(tmpdat_pLI_tol)))
      output_pLI_tol_raw <- cbind.data.frame(output_pLI_tol_raw, rowSums(tmpdat_pLI_tol,na.rm=TRUE))
      colnames(output_pLI_tol_raw)[length(names(output_pLI_tol_raw))] <- tmpfilename
      output_pLI_tol_raw.count <- output_pLI_tol_raw.count + dim(tmpdat_pLI_tol)[2]
      
    }

    output_gw_raw$burdensum        <- rowSums(output_gw_raw[,-which(names(tmpdat) %in% c("eid_sample"))])
    output_pLI_intol_raw$burdensum <- rowSums(output_pLI_intol_raw[,-which(names(tmpdat) %in% c("eid_sample"))])
    output_pLI_tol_raw$burdensum   <- rowSums(output_pLI_tol_raw[,-which(names(tmpdat) %in% c("eid_sample"))])
    output_gw <- output_gw_raw[,c("eid_sample","burdensum")]
    output_pLI_intol <- output_pLI_intol_raw[,c("eid_sample","burdensum")]
    output_pLI_tol <- output_pLI_tol_raw[,c("eid_sample","burdensum")]

    write.table(output_gw, paste0("ukbb.gw.maf",maf,".",annot,".N",output_gw_raw.count,".missensesum.txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
    write.table(output_pLI_intol, paste0("ukbb.pLI_intol.maf",maf,".",annot,".N",output_pLI_intol_raw.count,".missensesum.txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")
    write.table(output_pLI_tol, paste0("ukbb.pLI_tol.maf",maf,".",annot,".N",output_pLI_tol_raw.count,".missensesum.txt"), col.names=TRUE, row.names=FALSE, quote=FALSE,sep=" ")

    head(output_gw_raw.count)
    head(output_pLI_intol_raw.count)
    head(output_pLI_tol_raw.count)
  }
}