library(data.table)
library(dplyr)

irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}

setwd("/MYPATH/")

#-----------------------------
# parse sex covariate
#-----------------------------
#-------------------
sex <- fread("/MYPATH/MYFILE.tsv",header=TRUE,stringsAsFactors=FALSE)[,c("f_eid","f_31_0_0")]
colnames(sex) <- c("f_eid","sex")

#-----------------------------
# parse cognitive function phenotypes
#-----------------------------
#-------------------
edu <- read.csv("/MYPATH/MYFILE.csv",stringsAsFactors=FALSE)
edu$f_edu_baseline_age_mean0 <- edu$f_edu_baseline_age - mean(edu$f_edu_baseline_age,na.rm=TRUE)
edu$f_edu_baseline_age_mean02 <- edu$f_edu_baseline_age_mean0**2
edu <- edu[which(edu$f_6138_prefernot==0),]
table(edu$f_6138_inyr,useNA="always")
edu$f_6138_inyr[which(edu$f_6138_other==1)] <- 7
table(edu$f_6138_inyr,useNA="always")
edu <- edu[,c("f_eid","f_6138_inyr","f_edu_baseline_age_mean0","f_edu_baseline_age_mean02")]
colnames(edu) <- c("f_eid","edu_baseline","edu_baseline_age_mean0","edu_baseline_age_mean02")
#-------------------
rt <- fread("/MYPATH/MYFILE.tsv",header=TRUE,stringsAsFactors=FALSE)[,c("f_eid", "rt_baseline","rt_baseline_age_mean0","rt_baseline_age_mean02")]
#-------------------
fi_base <- fread("/MYPATH/MYFILE.tsv",header=TRUE,stringsAsFactors=FALSE)[,c("f_eid", "fiall_baseline","fi_baseline_age_mean0","fi_baseline_age_mean02","finum_baseline", "fiver_baseline")]
fi_base <- fi_base[,c("f_eid", "fiall_baseline", "fi_baseline_age_mean0","fi_baseline_age_mean02","finum_baseline", "fi_baseline_age_mean0","fi_baseline_age_mean02", "fiver_baseline", "fi_baseline_age_mean0","fi_baseline_age_mean02")]
colnames(fi_base) <- c("f_eid", "fiall_baseline", "fiall_baseline_age_mean0","fiall_baseline_age_mean02","finum_baseline", "finum_baseline_age_mean0","finum_baseline_age_mean02", "fiver_baseline", "fiver_baseline_age_mean0","fiver_baseline_age_mean02")
#-------------------
pheno_raw <- Reduce(function(x,y) left_join(x,y,by="f_eid"), list(sex,edu,rt,fi_base))
#-------------------
pheno_raw$edu_baseline_irnt <- irnt(pheno_raw$edu_baseline,seed=0)
pheno_raw$rt_baseline_irnt <- irnt(pheno_raw$rt_baseline,seed=0)
pheno_raw$fiall_baseline_irnt <- irnt(pheno_raw$fiall_baseline,seed=0)
pheno_raw$finum_baseline_irnt <- irnt(pheno_raw$finum_baseline,seed=0)
pheno_raw$fiver_baseline_irnt <- irnt(pheno_raw$fiver_baseline,seed=0)
#-------------------
pheno_raw$edu_baseline_age_mean0_sex <- pheno_raw$edu_baseline_age_mean0*pheno_raw$sex
pheno_raw$rt_baseline_age_mean0_sex <- pheno_raw$rt_baseline_age_mean0*pheno_raw$sex
pheno_raw$fiall_baseline_age_mean0_sex <- pheno_raw$fiall_baseline_age_mean0*pheno_raw$sex
pheno_raw$finum_baseline_age_mean0_sex <- pheno_raw$finum_baseline_age_mean0*pheno_raw$sex
pheno_raw$fiver_baseline_age_mean0_sex <- pheno_raw$fiver_baseline_age_mean0*pheno_raw$sex
pheno_raw$edu_baseline_age_mean02_sex <- pheno_raw$edu_baseline_age_mean02*pheno_raw$sex
pheno_raw$rt_baseline_age_mean02_sex <- pheno_raw$rt_baseline_age_mean02*pheno_raw$sex
pheno_raw$fiall_baseline_age_mean02_sex <- pheno_raw$fiall_baseline_age_mean02*pheno_raw$sex
pheno_raw$finum_baseline_age_mean02_sex <- pheno_raw$finum_baseline_age_mean02*pheno_raw$sex
pheno_raw$fiver_baseline_age_mean02_sex <- pheno_raw$fiver_baseline_age_mean02*pheno_raw$sex
#-------------------
idmap <- fread("MYPATH/MYFILE.csv")[,c(1,2,5)]
colnames(idmap) <- c("IID", "exomeID", "f_eid" )
pheno_raw <- left_join(idmap, pheno_raw, by="f_eid")
#-------------------
write.table(pheno_raw,"/MYPATH/MYFILE.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")

#-----------------------------
# add SES covariates
#-----------------------------
ses <- read.csv("/MYPATH/MYFILE.csv")
ses <- ses[,c("f.eid","f.54.0.0","f.189.0.0","f.738.0.0")]
colnames(ses) <- c("f_eid","assess_center","Townsend","income") 
# format income f.738
summary(factor(ses$income))
ses$income[which(ses$income==-1 | ses$income ==-3)] <- NA
summary(factor(ses$income))
ses$income2 <- 0
ses$income3 <- 0
ses$income4 <- 0
ses$income5 <- 0
ses$income2[is.na(ses$income)==TRUE] <- NA
ses$income3[is.na(ses$income)==TRUE] <- NA
ses$income4[is.na(ses$income)==TRUE] <- NA
ses$income5[is.na(ses$income)==TRUE] <- NA
ses$income2[which(ses$income==2)] <- 1
ses$income3[which(ses$income==3)] <- 1
ses$income4[which(ses$income==4)] <- 1
ses$income5[which(ses$income==5)] <- 1
table(ses$income, ses$income2, useNA="always")
table(ses$income, ses$income3, useNA="always")
table(ses$income, ses$income4, useNA="always")
table(ses$income, ses$income5, useNA="always")

# format assessment center f.54
ses$assess_center <- factor(ses$assess_center)
summary(ses$assess_center)
assess_center_dummy <- model.matrix(~ -1+assess_center,data=ses)
# use this largest category as reference
ses <- cbind(ses,assess_center_dummy)
pheno_ses_raw <- left_join(pheno_raw, ses, by="f_eid")
#-------------------
write.table(pheno_ses_raw,"/MYPATH/MYFILE.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")

#-----------------------------
# Create phenotype files for REGENIE and plain burden analysis
#-----------------------------
# sample QC based on Sex chromosome aneuploidy (f_22019_0_0), inconsistency between genetic and self-reported sex (f_22001_0_0, f_31_0_0), and het and missing (f_22027_0_0)
geno_remove <- fread("/MYPATH/MYFILE.remove",header=FALSE,stringsAsFactors=FALSE)
pheno_sampleqc <- pheno_ses_raw[-which(pheno_ses_raw$f_eid %in% geno_remove$V1),]

# make population specific groups with PCs
pc_sas <- fread("/MYPATH/MYFILE_ukb_imp_SAS.eigenvec")[,2:42]
colnames(pc_sas)[1] <- c("f_eid")
pc_afr <- fread("/MYPATH/MYFILE_ukb_imp_AFR.eigenvec")[,2:42]
colnames(pc_afr)[1] <- c("f_eid")
pc_eur <- fread("/MYPATH/MYFILE_ukb_imp_EUR.eigenvec")[,2:42]
colnames(pc_eur)[1] <- c("f_eid")
pheno_sampleqc_eur <- inner_join(pheno_sampleqc, pc_eur, by="f_eid")
pheno_sampleqc_sas <- inner_join(pheno_sampleqc, pc_sas, by="f_eid")
pheno_sampleqc_afr <- inner_join(pheno_sampleqc, pc_afr, by="f_eid")

str(pheno_sampleqc_eur)
str(pheno_sampleqc_sas)
str(pheno_sampleqc_afr)

write.table(pheno_sampleqc_eur,"/MYPATH/MYFILE.cogphenosespc.EUR.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_sas,"/MYPATH/MYFILE.cogphenosespc.SAS.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_afr,"/MYPATH/MYFILE.cogphenosespc.AFR.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")

colname_rearrange <- c("f_eid", "exomeID", "IID", names(pheno_sampleqc_eur)[4:length(names(pheno_sampleqc_eur))])
pheno_sampleqc_eur_feid <- as.data.frame(pheno_sampleqc_eur)[,colname_rearrange]
colnames(pheno_sampleqc_eur_feid) <- c("IID", "exomeIDshort", "exomeID", names(pheno_sampleqc_eur)[4:length(names(pheno_sampleqc_eur))])
pheno_sampleqc_sas_feid <- as.data.frame(pheno_sampleqc_sas)[,colname_rearrange]
colnames(pheno_sampleqc_sas_feid) <- c("IID", "exomeIDshort", "exomeID", names(pheno_sampleqc_sas)[4:length(names(pheno_sampleqc_sas))])
pheno_sampleqc_afr_feid <- as.data.frame(pheno_sampleqc_afr)[,colname_rearrange]
colnames(pheno_sampleqc_afr_feid) <- c("IID", "exomeIDshort", "exomeID", names(pheno_sampleqc_afr)[4:length(names(pheno_sampleqc_afr))])
write.table(pheno_sampleqc_eur_feid,"/MYPATH/MYFILE.cogphenosespc.EUR.feid.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_sas_feid,"/MYPATH/MYFILE.cogphenosespc.SAS.feid.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_afr_feid,"/MYPATH/MYFILE.cogphenosespc.AFR.feid.v3.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")

# unrelated samples
unrelated <- fread("/MYPATH/MYFILE.unrelated.keep")
pheno_sampleqc_eur_unrel <- pheno_sampleqc_eur[which(pheno_sampleqc_eur$f_eid %in% unrelated$V1),]
pheno_sampleqc_sas_unrel <- pheno_sampleqc_sas[which(pheno_sampleqc_sas$f_eid %in% unrelated$V1),]
pheno_sampleqc_afr_unrel <- pheno_sampleqc_afr[which(pheno_sampleqc_afr$f_eid %in% unrelated$V1),]

str(pheno_sampleqc_eur_unrel)
str(pheno_sampleqc_sas_unrel)
str(pheno_sampleqc_afr_unrel)

write.table(pheno_sampleqc_eur_unrel,"/MYPATH/MYFILE.cogphenosespc.EUR.unrel.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_sas_unrel,"/MYPATH/MYFILE.cogphenosespc.SAS.unrel.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_afr_unrel,"/MYPATH/MYFILE.cogphenosespc.AFR.unrel.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")

colname_rearrange <- c("f_eid", "exomeID", "IID", names(pheno_sampleqc_eur_unrel)[4:length(names(pheno_sampleqc_eur_unrel))])
pheno_sampleqc_eur_unrel_feid <- as.data.frame(pheno_sampleqc_eur_unrel)[,colname_rearrange]
colnames(pheno_sampleqc_eur_unrel_feid) <- c("IID", "exomeID", "exomeIDshort", names(pheno_sampleqc_eur_unrel)[4:length(names(pheno_sampleqc_eur_unrel))])
pheno_sampleqc_sas_unrel_feid <- as.data.frame(pheno_sampleqc_sas_unrel)[,colname_rearrange]
colnames(pheno_sampleqc_sas_unrel_feid) <- c("IID", "exomeID", "exomeIDshort", names(pheno_sampleqc_sas_unrel)[4:length(names(pheno_sampleqc_sas_unrel))])
pheno_sampleqc_afr_unrel_feid <- as.data.frame(pheno_sampleqc_afr_unrel)[,colname_rearrange]
colnames(pheno_sampleqc_afr_unrel_feid) <- c("IID", "exomeID", "exomeIDshort", names(pheno_sampleqc_afr_unrel)[4:length(names(pheno_sampleqc_afr_unrel))])
write.table(pheno_sampleqc_eur_unrel_feid,"/MYPATH/MYFILE.EUR.unrel.feid.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_sas_unrel_feid,"/MYPATH/MYFILE.SAS.unrel.feid.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")
write.table(pheno_sampleqc_afr_unrel_feid,"/MYPATH/MYFILE.AFR.unrel.feid.txt",col.names=TRUE,row.names=FALSE,quote=FALSE,sep=" ")


