args <- commandArgs(trailingOnly = TRUE)
chr <- args[1]
maf <- as.numeric(args[2])
annot <- args[3]

library(dplyr)

# given gene_table and list of samples, create x matrix for each gene (exome id as row, variant burden as column)
make_x_mat <- function(gene_table,all_inds){
  n_samples <- length(all_inds)
  count_table <- c()
  for (i in 1:length(gene_table[,1])){
  tmpdat <- as.data.frame(matrix((unlist(strsplit(unlist(strsplit(as.character(gene_table$carriers[i]),",")), ":"))),ncol=2,byrow=TRUE),stringsAsFactors=FALSE)
  colnames(tmpdat) <- c("eid_sample","count")
  tmpdat$count <- as.numeric(tmpdat$count)
  tmpdat <- tmpdat[order(-tmpdat$count),]
  tmpdat <- tmpdat[duplicated(tmpdat$eid_sample)==FALSE,]
  count_table <- rbind(count_table,tmpdat)
  }
  burden_table <- count_table %>%
    group_by(eid_sample) %>%
    mutate("burden" = cumsum(count)) %>%
    select(-count)
  burden_table <- as.data.frame(burden_table)
  burden_table <- burden_table[order(-burden_table$burden),]
  burden_table <- burden_table[duplicated(burden_table$eid_sample)==FALSE,]
  rm(count_table)
  gc()
  x_mat <- data.frame(all_inds, stringsAsFactors=FALSE)
  colnames(x_mat) <- c("eid_sample")
  # x_mat_output <- merge(x_mat,burden_table,by="eid_sample",all.x=TRUE)
  x_mat_output <- left_join(x_mat,burden_table,by="eid_sample",all.x=TRUE)
  x_mat_output[is.na(x_mat_output$burden)==TRUE,"burden"] <- 0
  return(x_mat_output)
}
  
samplelist_raw <- read.csv("/MYPATH/MYFILE.csv",header=TRUE,stringsAsFactors=FALSE)
exomeID <- samplelist_raw$sample

inputfilepath <- paste0("/MYPATH/UKB_missense/chr",chr,"_",annot,"_carriers.txt.gz")
data_raw <- read.table(inputfilepath,header=TRUE,stringsAsFactors=FALSE)
data_raw <- data_raw[union(which(data_raw$alt_af < maf),which(data_raw$alt_af > (1-maf))),]

# remove variants with no carriers
missing_lofs <- which(is.na(data_raw$carriers)==TRUE)
if(length(missing_lofs) > 0){
  data_raw <- data_raw[-missing_lofs,]
}

genelist <- unique(data_raw$gene)

start_time <- Sys.time()

output1 <- as.data.frame(exomeID,stringsAsFactors=FALSE)
colnames(output1) <- "eid_sample"
output2 <- c()
for (j in genelist){
  gene = j
  print(gene)  # create z matrix for each gene
  data_gene <- data_raw[which(data_raw$gene == gene),]
  x <- make_x_mat(data_gene,exomeID) 
  colnames(x) <- c("eid_sample",gene)
  n_ptv <- sum(x[,gene], na.rm = TRUE)    # n.ptv on that gene
  n_carriers <- length(x[which(x[,gene] > 0),1])
  n_variants <- length(data_gene[is.null(data_gene$carriers) == FALSE,1])
  if(n_carriers == 0){
    next()
  }else{
    output1 <- left_join(output1,x,by="eid_sample")
    output2 <- rbind(output2,c(gene,n_variants,n_carriers,n_ptv))
  }
}
colnames(output2) <- c("gene","n_variants","n_carriers","n_counts")

end_time <- Sys.time()
end_time - start_time

write.table(as.data.frame(output2),paste0("/MYPATH/ukbb_chr",chr,".maf",strsplit(format(maf,scientific=FALSE),"[.]")[[1]][2],".",annot,".info.tsv"),quote=FALSE,sep="\t",col.names=TRUE,row.names=FALSE)
write.table(as.data.frame(output1),paste0("/MYPATH/ukbb_chr",chr,".maf",strsplit(format(maf,scientific=FALSE),"[.]")[[1]][2],".",annot,".tsv"),quote=FALSE,sep="\t",col.names=TRUE,row.names=FALSE)
