############################################################
# Extended Data Figure 2
############################################################
# MPC1_0: missense with 2 >= MPC > 0
# MPC1_2: missense with 3 >= MPC > 2
# MPC1_3: missense with MPC > 3

#===========================================================
# plot
library(data.table)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(ggpubr)

#===========================================================
# Educational attainment
#===========================================================
dat_plot <- fread("ukbb.dd285ddg2pasdgenes.association.summary.plot.csv")
dat_plot$upper <- dat_plot$BETA+dat_plot$SE*1.96
dat_plot$lower <- dat_plot$BETA-dat_plot$SE*1.96
dat_plot$Burden <- factor(dat_plot$Burden)
dat_plot$Variant_category <- factor(dat_plot$Variant_category, levels = c("ptv", "missense_MPC1_3", "missense_MPC1_2", "missense_MPC1_0", "synonymous" ))
dat_plot_tmp <- dat_plot

#---------------------------------------
# gene-based burden
#---------------------------------------
dat_plot_tmp_edu.ddg2p <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Educational attainment" & dat_plot_tmp$Gene_set=="ddg2p"),]
p1 <- ggplot(dat_plot_tmp_edu.ddg2p, aes(y=rev(rank_per_pheno), x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=c('#ff9600','#ffab00','#ffc000','#ffd600','#ffeb00'),labels=c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=seq(-0.25,0.05,0.1), limits=c(-0.25,0.05)) + 
scale_y_continuous(limits = c(0.5,5.5), breaks = rev(dat_plot_tmp_edu.ddg2p$rank_per_pheno), labels = c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black", alpha=0.5) +
theme_classic() + 
theme(legend.position = "NULL",plot.title=element_text(size=10)) + 
labs(y = "", x = expression(beta), title = "Educational attainment\nDDG2P genes") +
annotate("text", x=-0.25, y=5, label= "1604", hjust = 0, size=3) + 
annotate("text", x=-0.25, y=4, label= "251", hjust = 0, size=3) + 
annotate("text", x=-0.25, y=3, label= "546", hjust = 0, size=3) + 
annotate("text", x=-0.25, y=2, label= "1741", hjust = 0, size=3) + 
annotate("text", x=-0.25, y=1, label= "1609", hjust = 0, size=3) 

#===========================================================
# Verbal-numerical reasoning
#===========================================================
#---------------------------------------
# gene-based burden
#---------------------------------------
dat_plot_tmp_edu.ddg2p <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Verbal-numerical reasoning (baseline)" & dat_plot_tmp$Gene_set=="ddg2p"),]
p2 <- ggplot(dat_plot_tmp_edu.ddg2p, aes(y=rev(rank_per_pheno), x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=rev(c('#c7e9b4','#7fcdbb','#41b6c4','#1d91c0','#225ea8')),labels=c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=c(-0.2,-0.1,0,0.1), limits=c(-0.25,0.2)) + 
scale_y_continuous(limits = c(0.5,5.5), breaks = rev(dat_plot_tmp_edu.ddg2p$rank_per_pheno), labels = c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black", alpha=0.5) +
theme_classic() + 
theme(legend.position = "NULL",plot.title=element_text(size=10),axis.text.y=element_blank(),axis.title.y=element_blank()) + 
labs(y = "", x = expression(beta), title = "Verbal-numerical reasoning\nDDG2P genes") # +

#===========================================================
# Reaction time
#===========================================================
#---------------------------------------
# gene-based burden
#---------------------------------------
dat_plot_tmp_rt.ddg2p <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Reaction time" & dat_plot_tmp$Gene_set=="ddg2p"),]
p3 <- ggplot(dat_plot_tmp_rt.ddg2p, aes(y=rev(rank_per_pheno), x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=rev(c('#fcc5c0','#fa9fb5','#f768a1','#dd3497','#ae017e')),labels=c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=c(-0.05,0,0.05,0.1,0.15), limits=c(-0.05,0.2)) + 
scale_y_continuous(limits = c(0.5,5.5), breaks = rev(dat_plot_tmp_rt.ddg2p$rank_per_pheno), labels = c("PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black", alpha=0.5) +
theme_classic() + 
theme(legend.position = "NULL",plot.title=element_text(size=10),axis.text.y=element_blank(),axis.title.y=element_blank()) + 
labs(y = "", x = expression(beta), title = "Reaction time\nDDG2P genes") 

#---------------------------------------
# Compare p-values from studies
#---------------------------------------
edu <- fread("edu_baseline_irnt.ptv.maf00001.regenie.qc.txt")
fiall <- fread("fiall_baseline_irnt.ptv.maf00001.regenie.qc.txt")
rt <- fread("rt_baseline_irnt.ptv.maf00001.regenie.qc.txt")
dd <- fread("41586_2020_2832_MOESM4_ESM.DDgene_exome_sumstat.csv")
asd <- fread("ASD_exome_gene_pvalue.plot.csv")

annot_table_raw <- read.table("/MYPATH/gnomad.v2.1.1.lof_metrics.by_gene.txt.bgz",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table <- annot_table_raw[,c("gene","pLI")]
annot_table$pLI <- as.numeric(annot_table$pLI)

ddg2p.file <- read.csv("DDG2P_23_12_2020.csv",stringsAsFactors=FALSE)
ddg2p_highconf <- ddg2p.file$gene.symbol[which(ddg2p.file$DDD.category=="confirmed" | ddg2p.file$DDD.category=="probable")]
ddg2p_all <- ddg2p.file$gene.symbol

asd_sig_list <- c("CHD8", "SCN2A", "SYNGAP1", "ADNP", "FOXP1", "POGZ", "ARID1B", "SUV420H1", "DYRK1A", "SLC6A1", "GRIN2B", "PTEN", "SHANK3", "MED13L", "GIGYF1", "CHD2", "ANKRD11", "ANK2", "ASH1L", "TLK2", "DNMT3A", "DEAF1", "CTNNB1", "KDM6B", "DSCAM", "SETD5", "KCNQ3", "SRPR", "KDM5B", "WAC", "SHANK2", "NRXN1", "TBL1XR1", "MYT1L", "BCL11A", "RORB", "RAI1", "DYNC1H1", "DPYSL2", "AP2S1", "KMT2C", "PAX5", "MKX", "GABRB3", "SIN3A", "MBD5", "MAP1A", "STXBP1", "CELF4", "PHF12", "TBR1", "PPP2R5D", "TM9SF4", "PHF21A", "PRR12", "SKI", "ASXL3", "SPAST", "SMARCC2", "TRIP12", "CREBBP", "TCF4", "CACNA1E", "GNAI1", "TCF20", "FOXP2", "NSD1", "TCF7L2", "LDB1", "EIF3G", "PHF2", "KIAA0232", "VEZF1", "GFAP", "IRF2BPL", "ZMYND8", "SATB1", "RFX3", "SCN1A", "PPP5C", "TRIM23", "TRAF7", "ELAVL3", "GRIA2", "LRRC4C", "CACNA2D3", "NUP155", "KMT2E", "NR3C2", "NACC1", "PTK7", "PPP1R9B", "GABRB2", "HDLBP", "TAOK1", "UBR1", "TEK", "KCNMA1", "CORO1A", "HECTD4", "NCOA1", "DIP2A")

edu_dd <- merge(edu,dd,by.x="GENE",by.y="symbol",all=TRUE)
head(edu_dd)
summary(edu_dd)

edu_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "SLC8A1", "BCAS3")
vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A")
eduvnr_gene_list <- unique(c(edu_gene_list, vnr_gene_list))

edu_dd$sigset <- "NO"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list)] <- "EDU"
edu_dd$sigset[which(edu_dd$GENE %in% ddg2p_highconf)] <- "DDG2P"
edu_dd$sigset[which(edu_dd$GENE %in% asd_sig_list)] <- "ASD"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% ddg2p_highconf)] <- "DDG2P & EDU"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% asd_sig_list)] <- "EDU & ASD"
edu_dd$sigset[which(edu_dd$GENE %in% asd_sig_list & edu_dd$GENE %in% ddg2p_highconf)] <- "ASD & DDG2P"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% asd_sig_list & edu_dd$GENE %in% ddg2p_highconf)] <- "EDU & DDG2P & ASD"
edu_dd$sigset <- factor(edu_dd$sigset, levels=c("ASD","ASD & DDG2P","DDG2P","DDG2P & EDU","EDU & ASD","EDU","EDU & DDG2P & ASD"))

edu_dd$sig_all <- "NO"
edu_dd[edu_dd$sigset!="NO","sig_all"] <- "YES"

edu_dd_pli <- merge(edu_dd, annot_table, by.x="GENE", by.y="gene", all=TRUE)
edu_dd_pli.sig <- edu_dd_pli[which(edu_dd_pli$sig_all == "YES"),]
table(edu_dd_pli$sigset)
summary(factor(edu_dd_pli$sig_all))
edu_dd_pli.plot <- edu_dd_pli[which(edu_dd_pli$sig_all == "YES"), c("GENE", "pLI", "denovoWEST_p_full","PTV_enrichment_p", "BETA", "SE", "P", "NSAMPLE", "NPTV", "NCARRIER", "sigset", "sig_all")]
edu_dd_pli.plot[which(edu_dd_pli.plot$PTV_enrichment_p==0),"PTV_enrichment_p"] <- 10^-18
#-------------------
# make plots
#-------------------
edu_dd_qc.plot <- as.data.frame(edu_dd_pli.plot)
edu_dd_qc.plot$GENE_label <- NA
edu_dd_qc.plot[which(edu_dd_qc.plot$sigset=="EDU" | edu_dd_qc.plot$sigset=="EDU & DDG2P & ASD" | edu_dd_qc.plot$sigset=="DDG2P & EDU" | edu_dd_qc.plot$sigset=="EDU & ASD"),"GENE_label"] <- edu_dd_qc.plot[which(edu_dd_qc.plot$sigset=="EDU" | edu_dd_qc.plot$sigset=="EDU & DDG2P & ASD" | edu_dd_qc.plot$sigset=="DDG2P & EDU" | edu_dd_qc.plot$sigset=="EDU & ASD"),"GENE"] 
edu_dd_qc.plot[order(edu_dd_qc.plot$P),] # MAP1A

p4 <- ggplot(data=edu_dd_qc.plot, aes(y=-log10(P), x=-log10(PTV_enrichment_p))) + 
geom_point(aes(color=sigset, alpha=pLI, size=pLI)) +
geom_point(data=edu_dd_qc.plot[which(edu_dd_qc.plot$sigset=="ASD & DDG2P"),],aes(color=sigset, alpha=pLI, size=pLI)) +
geom_point(data=edu_dd_qc.plot[which(edu_dd_qc.plot$sigset=="ASD"),],aes(color=sigset, alpha=pLI, size=pLI)) +
scale_size_continuous(range = c(2, 6)) +
scale_alpha_continuous(range = c(1,0.3) ) +
theme_classic() +
scale_x_continuous(name=expression(-log[10](italic(P))~~"for PTV DNM enrichment with DD"), breaks=seq(0,19,2), limits=c(0,19), labels=c("0","2","4","6","8","10","12","14","16",">16")) +
scale_y_continuous(name=expression(-log[10](italic(P))~~"for PTV burden assoc. with EDU"), breaks=seq(0,13,2), limits=c(0,13)) +
geom_text_repel(seed=3, data=edu_dd_qc.plot, aes(label=GENE_label, fontface="italic"), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, nudge_y=1) +
scale_color_manual(values = c("#1f78b4", "#33a02c", "#ffd500", "#FF4500", "#54278f", "#bd0026", "black"), name="Exome-wide significant" ) +
theme(legend.position = "none", legend.text = element_text(size = 8), axis.title.y=element_text(size=8), axis.title.x=element_text(size=8)) +
labs(title="PTV DNM enrichment") 

p4

p5 <- ggplot(data=edu_dd_qc.plot, aes(y=-log10(P), x=-log10(denovoWEST_p_full))) + 
geom_point(aes(color=sigset, alpha=pLI, size=pLI)) +
scale_size_continuous(range = c(2, 6)) +
scale_alpha_continuous(range = c(1,0.4) ) +
theme_classic() +
scale_x_continuous(name=expression(-log[10](italic(P))~~"for DeNovoWEST with DD"), breaks=seq(0,22,2), limits=c(0,22)) +
scale_y_continuous(name=expression(-log[10](italic(P))~~"for PTV burden assoc. with EDU"), breaks=seq(0,13,2), limits=c(0,13)) +
geom_text_repel(seed=3, data=edu_dd_qc.plot, aes(label=GENE_label, fontface="italic"), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, nudge_y=1) +
# scale_color_manual(values = c("#1f78b4", "#33a02c", "#ffd500", "#54278f", "#bd0026", "black"), name="Exome-wide significant" ) +
scale_color_manual(values = c("#1f78b4", "#33a02c", "#ffd500", "#bd0026", "black"), name="Exome-wide significant" ) +
theme(legend.position = "right", legend.text = element_text(size = 8), axis.title.y=element_text(size=8), axis.title.x=element_text(size=8)) +
labs(title="DeNovoWEST") +
guides(size = FALSE, alpha = FALSE)  

p5

#===========================================================
# Verbal-numerical reasoning
#===========================================================
vnr_dd <- merge(fiall,dd,by.x="GENE",by.y="symbol",all=TRUE)
head(vnr_dd)
summary(vnr_dd)

vnr_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "SLC8A1", "BCAS3")
vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A")
# vnr_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "ANKRD12", "SLC8A1", "BCAS3", "NDUFA6", "MAP1A")
# vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A", "ARHGEF7", "C11orf94", "KIF26A")
vnrvnr_gene_list <- unique(c(vnr_gene_list, vnr_gene_list))

vnr_dd$sigset <- "NO"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list)] <- "VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% ddg2p_highconf)] <- "DDG2P"
vnr_dd$sigset[which(vnr_dd$GENE %in% asd_sig_list)] <- "ASD"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "DDG2P & VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% asd_sig_list)] <- "ASD & VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% asd_sig_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "ASD & DDG2P"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% asd_sig_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "VNR & DDG2P & ASD"
vnr_dd$sig_all <- "NO"
vnr_dd[vnr_dd$sigset!="NO","sig_all"] <- "YES"

vnr_dd$sig_all <- "NO"
vnr_dd[vnr_dd$sigset!="NO","sig_all"] <- "YES"

vnr_dd_pli <- merge(vnr_dd, annot_table, by.x="GENE", by.y="gene", all=TRUE)
vnr_dd_pli.sig <- vnr_dd_pli[which(vnr_dd_pli$sig_all == "YES"),]
table(vnr_dd_pli$sigset)
summary(factor(vnr_dd_pli$sig_all))
vnr_dd_pli.plot <- vnr_dd_pli[which(vnr_dd_pli$sig_all == "YES"), c("GENE", "pLI", "denovoWEST_p_full","PTV_enrichment_p", "BETA", "SE", "P", "NSAMPLE", "NPTV", "NCARRIER", "sigset", "sig_all")]
vnr_dd_pli.plot[which(vnr_dd_pli.plot$PTV_enrichment_p==0),"PTV_enrichment_p"] <- 10^-18
#-------------------
# make plots
#-------------------
vnr_dd_qc.plot <- as.data.frame(vnr_dd_pli.plot)
vnr_dd_qc.plot$GENE_label <- NA
vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="VNR" | vnr_dd_qc.plot$sigset=="VNR & DDG2P & ASD" | vnr_dd_qc.plot$sigset=="DDG2P & VNR" | vnr_dd_qc.plot$sigset=="ASD & VNR"),"GENE_label"] <- vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="VNR" | vnr_dd_qc.plot$sigset=="VNR & DDG2P & ASD" | vnr_dd_qc.plot$sigset=="DDG2P & VNR" | vnr_dd_qc.plot$sigset=="ASD & VNR"),"GENE"] 
vnr_dd_qc.plot[order(vnr_dd_qc.plot$P),] # MAP1A

p6 <- ggplot(data=vnr_dd_qc.plot, aes(y=-log10(P), x=-log10(PTV_enrichment_p))) + 
geom_point(aes(color=sigset, alpha=pLI, size=pLI)) +
geom_point(data=vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="ASD & DDG2P"),],aes(color=sigset, alpha=pLI, size=pLI)) +
geom_point(data=vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="ASD"),],aes(color=sigset, alpha=pLI, size=pLI)) +
scale_size_continuous(range = c(2, 6)) +
scale_alpha_continuous(range = c(1, 0.3) ) +
theme_classic() +
scale_x_continuous(name=expression(-log[10](italic(P))~~"for PTV DNM enrichment with DD"), breaks=seq(0,19,2), limits=c(0,19), labels=c("0","2","4","6","8","10","12","14","16",">16")) +
scale_y_continuous(name=expression(-log[10](italic(P))~~"for PTV burden assoc. with EDU"), breaks=seq(0,13,2), limits=c(0,13)) +
geom_text_repel(seed=3, data=vnr_dd_qc.plot, aes(label=GENE_label, fontface="italic"), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, nudge_y=1, fontface="italic") +
scale_color_manual(values = c("#1f78b4", "#33a02c", "#ffd500", "#FF4500", "#bd0026", "black"), name="Exome-wide significant" ) +
theme(legend.position = "none", legend.text = element_text(size = 8), axis.title.y=element_text(size=8), axis.title.x=element_text(size=8)) +
labs(title="PTV DNM enrichment") 

p6

#-------------------
# make plots
#-------------------
vnr_dd_qc.plot <- as.data.frame(vnr_dd_pli.plot)
vnr_dd_qc.plot$GENE_label <- NA
vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="VNR" | vnr_dd_qc.plot$sigset=="VNR & DDG2P & ASD" | vnr_dd_qc.plot$sigset=="DDG2P & VNR" | vnr_dd_qc.plot$sigset=="ASD & VNR"),"GENE_label"] <- vnr_dd_qc.plot[which(vnr_dd_qc.plot$sigset=="VNR" | vnr_dd_qc.plot$sigset=="VNR & DDG2P & ASD" | vnr_dd_qc.plot$sigset=="DDG2P & VNR" | vnr_dd_qc.plot$sigset=="ASD & VNR"),"GENE"] 
vnr_dd_qc.plot[order(vnr_dd_qc.plot$P),] # MAP1A

p7 <- ggplot(data=vnr_dd_qc.plot, aes(y=-log10(P), x=-log10(denovoWEST_p_full))) + 
geom_point(aes(color=sigset, alpha=pLI, size=pLI)) +
scale_size_continuous(range = c(2, 6)) +
scale_alpha_continuous(range = c(1,0.4) ) +
theme_classic() +
scale_x_continuous(name=expression(-log[10](italic(P))~~"for DeNovoWEST with DD"), breaks=seq(0,22,2), limits=c(0,22)) +
scale_y_continuous(name=expression(-log[10](italic(P))~~"for PTV burden assoc. with VNR"), breaks=seq(0,13,2), limits=c(0,13)) +
geom_text_repel(seed=3, data=vnr_dd_qc.plot, aes(label=GENE_label, fontface="italic"), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, nudge_y=1) +
scale_color_manual(values = c("#1f78b4", "#33a02c", "#ffd500", "#FF4500", "#bd0026", "black"), name="Exome-wide significant" ) +
theme(legend.position = "right", legend.text = element_text(size = 8), axis.title.y=element_text(size=8), axis.title.x=element_text(size=8)) +
labs(title="DeNovoWEST") 

p7

#---------------------------------------
# output 
#---------------------------------------
pp1 <- ggarrange(p1,p3,p2,widths=c(1.4,1,1),heights=c(1),labels=c("","",""),nrow=1,ncol=3)
pp11 <- ggarrange(p4,p5,widths=c(1,1.2),heights=c(1),labels=c("",""),nrow=1,ncol=2)
ppp11 <- annotate_figure(pp11,top = text_grob("Educational attainment", color = "black", size = 14, hjust=0.5,x=0.5, face = "bold")) 
pp12 <- ggarrange(p6,p7,widths=c(1,1.2),heights=c(1),labels=c("",""),nrow=1,ncol=2)
ppp12 <- annotate_figure(pp12,top = text_grob("Verbal-numerical reasoning", color = "black", size = 14, hjust=0.5,x=0.5, face = "bold")) 
pppp2 <- ggarrange(ppp11,ppp12,widths=c(1),heights=c(1,1),labels=c("",""),nrow=2,ncol=1)

ggarrange(pp1,pppp2,widths=c(1),heights=c(1,2.5),labels=c("a","b"),nrow=2,ncol=1)

