#===========================================================
# CACNA1A
#===========================================================
#-------------------
# format PTV carriers
#-------------------
library(data.table)
setwd("/home/cchen11/ukbb_cogexome/program_v5/cog_gene_lookup_run1")
irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
    	set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}

ptv_raw <- fread("CACNA1A_lof_carriers.txt")
ptv_raw <- ptv_raw[which(ptv_raw$alt_af<0.00001),]

output_raw <- c()
for (i in 1:length(ptv_raw$gene)){
	tmp_carriers <- ptv_raw$carriers[i]
	tmp_carriers_df <- as.data.frame(matrix(unlist(tstrsplit(unlist(tstrsplit(tmp_carriers, ",")),":")),ncol=2))
	tmp_carriers_df$V1 <- as.character(tmp_carriers_df$V1)
	tmp_carriers_df$V2 <- as.numeric(as.character(tmp_carriers_df$V2))
	tmp_carriers_df <- tmp_carriers_df[order(tmp_carriers_df$V2, decreasing=TRUE),]
	tmp_carriers_df <- tmp_carriers_df[which(duplicated(tmp_carriers_df$V1)==FALSE),]
	colnames(tmp_carriers_df) <- c("Carrier","PTVcount")
	tmp_carriers_df$gene <- "CACNA1A"
	tmp_output <- merge(ptv_raw[i,c("gene","chrom","pos","ref","alt","min_ref","min_alt","variant_id","vcf_variant_id","type","aa","alt_af")], tmp_carriers_df,by="gene",all.y=TRUE)
	output_raw <- rbind(output_raw,tmp_output)
}

#-------------------
# extract cog phenotype 
#-------------------
pheno_raw <- fread("/MYPATH/MYFILE.EUR.txt")

edu_baseline.lm <- lm(edu_baseline~sex+edu_baseline_age_mean0+edu_baseline_age_mean02+edu_baseline_age_mean0_sex+edu_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=pheno_raw)
pheno_raw$edu_baseline_resid[is.na(pheno_raw$edu_baseline)==FALSE] <- residuals(edu_baseline.lm)
pheno_raw$edu_baseline_resid_irnt[is.na(pheno_raw$edu_baseline)==FALSE] <- irnt(residuals(edu_baseline.lm))

fiall_baseline.lm <- lm(fiall_baseline~sex+fiall_baseline_age_mean0+fiall_baseline_age_mean02+fiall_baseline_age_mean0_sex+fiall_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=pheno_raw)
pheno_raw$fiall_baseline_resid[is.na(pheno_raw$fiall_baseline)==FALSE] <- residuals(fiall_baseline.lm)
pheno_raw$fiall_baseline_resid_irnt[is.na(pheno_raw$fiall_baseline)==FALSE] <- irnt(residuals(fiall_baseline.lm))

ptv_pheno_raw <- merge(output_raw,pheno_raw,by.x="Carrier",by.y="IID",all=FALSE)
summary(ptv_pheno_raw)
ptv_pheno_raw <- as.data.frame(ptv_pheno_raw)

#-------------------
# extract ICD code
#-------------------
icd10_raw <- as.data.frame(fread("/MYPATH/all_ICD10_20200901.pheno.v2.tsv.gz"))
icdlist <- names(icd10_raw)[2:length(names(icd10_raw))]

ptv_pheno_icd_raw <- merge(ptv_pheno_raw, icd10_raw, by.x="f_eid", by.y="IND", all=FALSE)

icd_count <- as.data.frame(colSums(ptv_pheno_icd_raw[,icdlist]))
icd_count$icd10 <- rownames(icd_count)
colnames(icd_count) <- c("count","icd10")

icd_map <- as.data.frame(fread("/MYPATH/phewas_pheno_key.csv",header=FALSE))
colnames(icd_map) <- c("icd10","icd10_fullname")

icd_count_longname <- merge(icd_count, icd_map, by="icd10", all.x=TRUE)

fwrite(icd_count_longname, "CACNA1A_lof_carriers.icd_count.csv")

icd_count_neuropsych_longname <- icd_count_longname[which(icd_count_longname$icd10 %in% c("F329","G35","G409","G439")),]

fwrite(icd_count_neuropsych_longname, "CACNA1A_lof_carriers.neuropsych_count.csv")
fwrite(ptv_pheno_icd_raw, "CACNA1A_lof_carriers.cogphenosescovaricd10.csv")

#-------------------
# Make plot
#-------------------
library(data.table)
library(ggrepel)
library(ggplot2)

icd_count_neuropsych_longname <- fread("/MYPATH/CACNA1A_lof_carriers.neuropsych_count.csv")
ptv_pheno_icd_raw <- fread("/MYPATH/CACNA1A_lof_carriers.cogphenosescovaricd10.csv")

exon_pos <- rbind(c("47","13207313","13208053"),c("46","13208756","13209009"),c("45","13209312","13209498"),c("44","13210617","13210652"),c("43","13212103","13212216"),c("42","13212384","13212522"),c("41","13212631","13212740"),c("40","13214233","13214333"),c("39","13214501","13214608"),c("38","13224667","13224772"),c("37","13227431","13227527"),c("36","13230082","13230209"),c("35","13231710","13231860"),c("34","13234921","13235036"),c("33","13235209","13235274"),c("32","13235614","13235730"),c("31","13245182","13245265"),c("30","13252991","13253101"),c("29","13255095","13255259"),c("28","13257350","13257551"),c("27","13259564","13259701"),c("26","13261450","13261610"),c("25","13262734","13262833"),c("24","13275850","13275956"),c("23","13277069","13277128"),c("22","13283267","13283396"),c("21","13285068","13285206"),c("20","13286503","13286966"),c("19","13298544","13299353"),c("18","13300550","13300656"),c("17","13303546","13303613"),c("16","13303767","13303884"),c("15","13307782","13307854"),c("14","13308120","13308251"),c("13","13308416","13308528"),c("12","13312669","13312781"),c("11","13317112","13317321"),c("10","13330244","13330333"),c("9","13332869","13332925"),c("8","13334378","13334493"),c("7","13335806","13335909"),c("6","13359606","13359799"),c("5","13365317","13365469"),c("4","13371688","13371779"),c("3","13452876","13453015"),c("2","13455107","13455212"),c("1","13505932","13506224"))

exon_pos <- as.data.frame(exon_pos)
colnames(exon_pos) <- c("exon","start","end")
exon_pos$exon <- as.numeric(as.character(exon_pos$exon))
exon_pos$start <- as.numeric(as.character(exon_pos$start))
exon_pos$end <- as.numeric(as.character(exon_pos$end))
exon_pos$median <- (exon_pos$start + exon_pos$end)/2
exon_pos$exon_annot_odd <- rev(c(1,NA,3,NA,5,NA,7,NA,9,NA,11,NA,13,NA,NA,NA,NA,NA,19,NA,21,NA,23,NA,NA,NA,27,NA,NA,NA,31,NA,NA,NA,35,NA,NA,NA,39,NA,NA,NA,NA,NA,NA,NA,47))
exon_pos$exon_annot_even <- rev(c(NA,2,NA,4,NA,6,NA,NA,NA,10,NA,12,NA,NA,NA,NA,NA,18,NA,20,NA,NA,NA,24,NA,26,NA,NA,NA,30,NA,32,NA,NA,NA,NA,NA,38,NA,NA,NA,42,NA,NA,NA,NA,NA))

dat_plot <- as.data.frame(ptv_pheno_icd_raw)
dat_plot.edu <- dat_plot[,c("f_eid","pos","edu_baseline_resid_irnt")]
colnames(dat_plot.edu) <- c("f_eid","pos","pheno")
dat_plot.fiall <- dat_plot[,c("f_eid","pos","fiall_baseline_resid_irnt")]
colnames(dat_plot.fiall) <- c("f_eid","pos","pheno")
dat_plot.edu$pheno_group <- "edu"
dat_plot.fiall$pheno_group <- "fiall"
dat_plot <- rbind(dat_plot.edu,dat_plot.fiall)

dat_plot$annot <- NA
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F329==1),f_eid]),"annot"] <- "Depression"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$G409==1),f_eid]),"annot"] <- "Epilepsy"

# ADD clinvar annotation using the following annotation
dat_plot[which(dat_plot$f_eid %in% c(1319629)),"annot"] <- "p.Cys1844Ter" # Epileptic encephalopathy, early infantile, 42
dat_plot[which(dat_plot$f_eid %in% c(1993390, 3586630, 4415684)),"annot"] <- "Splice donor" # Episodic ataxia type 2
dat_plot[which(dat_plot$f_eid %in% c(2292463)),"annot"] <- "p.Arg1351Ter" # Episodic ataxia type 2
dat_plot[which(dat_plot$f_eid %in% c(2995689)),"annot"] <- "p.Leu1178fs" # Epileptic encephalopathy, early infantile, 42
dat_plot[which(dat_plot$f_eid %in% c(5212765)),"annot"] <- "p.Arg198Ter" # Epileptic encephalopathy, early infantile, 42


dat_plot$clinvar <- dat_plot$annot
dat_plot$clinvar[is.na(dat_plot$clinvar)==TRUE] <- "NO"
dat_plot$clinvar[which(dat_plot$annot=="Splice donor" | dat_plot$annot=="p.Arg1351Ter")] <- "Episodic ataxia, type 2 (OMIM #108500)"
dat_plot$clinvar[which(dat_plot$annot=="p.Cys1844Ter" | dat_plot$annot=="p.Leu1178fs" | dat_plot$annot=="p.Arg198Ter")] <- "Epileptic encephalopathy (OMIM #617106)"
dat_plot$clinvar <- factor(dat_plot$clinvar, levels=c("NO","Epileptic encephalopathy (OMIM #617106)","Episodic ataxia, type 2 (OMIM #108500)","Epilepsy","Depression"))

p1 <- ggplot(dat_plot) + 
geom_point(aes(x=pos,y=pheno, color=pheno_group, shape=clinvar, size=clinvar)) +
geom_line(aes(x=pos,y=pheno, color=pheno_group, group=pheno_group), stat = 'smooth',method='loess', formula = 'y ~ x',alpha=1) +
geom_ribbon(aes(x=pos, y=pheno, group=pheno_group),stat='smooth', method = "loess", se=TRUE, alpha=0.1, formula = 'y ~ x',color=NA) +
geom_hline(yintercept=0, linetype="dashed", color = "black", size=0.6) + 
theme_classic() +
scale_color_manual(name="", values=c("#0570b0","#ae017e"), labels=c("Educational attainment","Verbal-numerical reasoning")) +
scale_shape_manual(name="", values=c(16,18,17,15,6), labels=c("Not pathogenic/\nlikely pathogenic in Clinvar", "Epileptic encephalopathy\n(OMIM #617106)","Episodic ataxia, type 2\n(OMIM #108500)","Epilepsy","Depression")) +
scale_size_manual(name="", values=c(2,5,4,3,3), labels=c("Not pathogenic/\nlikely pathogenic in Clinvar", "Epileptic encephalopathy\n(OMIM #617106)","Episodic ataxia, type 2\n(OMIM #108500)","Epilepsy","Depression")) +
labs(x="Chromosome 19 position", y="Standardized, residualized phenotypes") +
theme(legend.position="right",legend.text = element_text(color="black",size=14),legend.title = element_blank(), axis.text.y=element_text(size=14),axis.text.x=element_text(size=14), axis.title.y=element_text(size=14),axis.title.x=element_text(size=14)) +
scale_y_continuous(breaks=c(-3,-2,-1,0,1,2,3), limits=c(-4,4.2)) +
labs(title = "CACNA1A")


for (i in 1:47){
	p1 <- p1 +	
	geom_segment(x = exon_pos[which(exon_pos$exon==i),"median"], y = 3.5, xend = exon_pos[which(exon_pos$exon==i),"median"], yend = 3.7,color="black") +
	annotate(geom="text", x=exon_pos[which(exon_pos$exon==i),"median"], y=3.9, label=exon_pos[which(exon_pos$exon==i),"exon_annot_odd"], color="black",size=4) +
	annotate(geom="text", x=exon_pos[which(exon_pos$exon==i),"median"], y=4.2, label=exon_pos[which(exon_pos$exon==i),"exon_annot_even"], color="black",size=4)
}
p1 <- p1 + geom_segment(x = exon_pos[which(exon_pos$exon==1),"median"], y = 3.6, xend = exon_pos[which(exon_pos$exon==47),"median"], yend = 3.6,color="black")

########################################
# Make table
library(data.table)
library(ggrepel)
library(ggplot2)

icd_count_neuropsych_longname <- fread("/MYPATH/CACNA1A_lof_carriers.neuropsych_count.csv")
ptv_pheno_icd_raw <- fread("/MYPATH/CACNA1A_lof_carriers.cogphenosescovaricd10.csv")

ptv_pheno_icd_raw <- as.data.frame(ptv_pheno_icd_raw)
ptv_pheno_icd <- ptv_pheno_icd_raw[,c("f_eid","pos","edu_baseline_resid_irnt","fiall_baseline_resid_irnt","F329","G35","G409","G439")]

icd_list <- c("F329","G35","G409","G439")

for (i in 1:length(icd_list)){
ptv_pheno_icd[which(ptv_pheno_icd[,icd_list[i]]==1),icd_list[i]] <- icd_list[i]
}

ptv_pheno_icd$ICD <- NA
for (i in 1:length(ptv_pheno_icd[,1])){
	ptv_pheno_icd$ICD[i] <- paste0(ptv_pheno_icd[i,icd_list],collapse=",")
}

fwrite(ptv_pheno_icd, "CACNA1A_annot_multiple.supplTable.csv")

dat_plot$exon <- NA
for (i in 1:47){
dat_plot[which(dat_plot$pos >= (exon_pos[which(exon_pos$exon==i),"start"]-5) & dat_plot$pos <= (exon_pos[which(exon_pos$exon==i),"end"]+5)),"exon"] <- i	
}
dat_plot[is.na(dat_plot$exon)==TRUE,]
dat_plot$exon <- factor(dat_plot$exon)

dat_plot$group_ptv <- NA
dat_plot[which(dat_plot$clinvar=="NO"),"group_ptv"] <- "normal"
dat_plot[which(dat_plot$clinvar=="Epileptic encephalopathy (OMIM #617106)"),"group_ptv"] <- "clinvar"
dat_plot[which(dat_plot$clinvar=="Episodic ataxia, type 2 (OMIM #108500)"),"group_ptv"] <- "clinvar"
dat_plot[which(dat_plot$clinvar=="Epilepsy"),"group_ptv"] <- "icd"
dat_plot[which(dat_plot$clinvar=="Depression"),"group_ptv"] <- "icd"
dat_plot$group_ptv <- factor(dat_plot$group_ptv, levels=c("icd","clinvar","normal"))
dat_plot$group_ptv <- relevel(dat_plot$group_ptv, ref = "normal")

summary(dat_plot)

dat_plot.edu <- dat_plot[which(dat_plot$pheno_group=="edu"),]
dat_plot.edu <- dat_plot.edu[is.na(dat_plot.edu$pheno)==FALSE,]
summary(dat_plot.edu)

library(dplyr)
dat_plot.edu %>%
  group_by(group_ptv) %>%
  summarise_at(vars(pheno), list(~length(.), ~ mean(., na.rm=TRUE), ~ sd(., na.rm = TRUE))) %>%
  as.data.frame()

edu.glm.fit <- glm(pheno~group_ptv , data=dat_plot.edu)
summary(edu.glm.fit)

summary(aov(pheno ~ group_ptv, data = dat_plot.edu))

t.test(dat_plot.edu[which(dat_plot.edu$group_ptv=="normal"),"pheno"],alternative = "two.sided")
t.test(dat_plot.edu[which(dat_plot.edu$group_ptv=="clinvar"),"pheno"],alternative = "two.sided")
t.test(dat_plot.edu[which(dat_plot.edu$group_ptv=="icd"),"pheno"],alternative = "two.sided")

dat_plot.edu %>%
  group_by(exon) %>%
  summarise_at(vars(pheno), list(~length(.), ~ mean(., na.rm=TRUE), ~ sd(., na.rm = TRUE))) %>%
  as.data.frame()

for (i in 1:47){
	if ( length(dat_plot.edu[which(dat_plot.edu$exon==i),"pheno"])>1 ){
		print(c(i,t.test(dat_plot.edu[which(dat_plot.edu$exon==i),"pheno"],alternative = "two.sided")$p.value))
	}else{
		print(c(i,"NA"))
	}
}

######################
dat_plot.fiall <- dat_plot[which(dat_plot$pheno_group=="fiall"),]
dat_plot.fiall <- dat_plot.fiall[is.na(dat_plot.fiall$pheno)==FALSE,]
summary(dat_plot.fiall)

library(dplyr)
dat_plot.fiall %>%
  group_by(group_ptv) %>%
  summarise_at(vars(pheno), list(~length(.), ~ mean(., na.rm=TRUE), ~ sd(., na.rm = TRUE))) %>%
  as.data.frame()

fiall.glm.fit <- glm(pheno~group_ptv , data=dat_plot.fiall)
summary(fiall.glm.fit)

t.test(dat_plot.fiall[which(dat_plot.fiall$group_ptv=="normal"),"pheno"],alternative = "two.sided")
t.test(dat_plot.fiall[which(dat_plot.fiall$group_ptv=="clinvar"),"pheno"],alternative = "two.sided")
t.test(dat_plot.fiall[which(dat_plot.fiall$group_ptv=="icd"),"pheno"],alternative = "two.sided")

dat_plot.fiall %>%
  group_by(exon) %>%
  summarise_at(vars(pheno), list(~length(.), ~ mean(., na.rm=TRUE), ~ sd(., na.rm = TRUE))) %>%
  as.data.frame()

for (i in 1:27){
	if ( length(dat_plot.fiall[which(dat_plot.fiall$exon==i),"pheno"])>1 ){
		print(c(i,t.test(dat_plot.fiall[which(dat_plot.fiall$exon==i),"pheno"],alternative = "two.sided")$p.value))
	}else{
		print(c(i,"NA"))
	}
}
