#===========================================================
# plotting the following results
#===========================================================
library(data.table)
library(dplyr)
library(ggrepel)
library(ggplot2)
library(ggpubr)

######################################################################
# Genome-wide burden in EUR
######################################################################
dat_plot <- fread("ukbb.allburden.association.summary.plot.csv")
dat_plot$upper <- dat_plot$BETA+dat_plot$SE*1.96
dat_plot$lower <- dat_plot$BETA-dat_plot$SE*1.96
dat_plot$Burden <- factor(dat_plot$Burden)
dat_plot$Variant_category <- factor(dat_plot$Variant_category, levels = c("PTV", "Missense (all)", "Missense (MPC>3)", "Missense (3>=MPC>2)", "Missense (other)", "Synonymous" ))
dat_plot_tmp <- dat_plot

# Educational attainment
dat_plot_tmp_edu <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Educational attainment"),]
dat_plot_tmp_edu$rank_plot <- rev(c(1,2,3,6,7,8,9,10,13,14,15))
p1 <- ggplot(dat_plot_tmp_edu, aes(y=rank_plot, x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=rev(c('#c7e9b4','#7fcdbb','#1d91c0','#225ea8', '#41b6c4','#081d58')),labels=c("PTV", "Missense (all)", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=c(-0.15,-0.1,-0.05,0,0.05), limits=c(-0.16,0.05)) + 
scale_y_continuous(limits = c(0,16), breaks = dat_plot_tmp_edu$rank_plot, labels = c("PTV", "Missense (all)", "Synonymous", "PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous", "PTV", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black",alpha=0.5) +
theme_classic() + 
theme(legend.position = "NULL",plot.title = element_text(size=10)) +
labs(y = "", x = expression(beta), title = "Educational attainment",size=10) +
annotate("text", x=-0.11, y=16, label= "Exome-wide", hjust = 1, fontface="bold", size=3) + 
annotate("text", x=-0.11, y=11, label= "pLI > 0.9", hjust = 1, fontface="bold", size=3) + 
annotate("text", x=-0.11, y=4, label= "pLI < 0.9", hjust = 1, fontface="bold", size=3) + 
coord_cartesian(xlim=c(-0.1,0.05), clip = 'off')

# Reaction time
dat_plot_tmp_rt <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Reaction time"),]
dat_plot_tmp_rt$rank_plot <- rev(c(1,2,3,6,7,8,9,10,13,14,15))
p2 <- ggplot(dat_plot_tmp_rt, aes(y=rank_plot, x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=rev(c('#c7e9b4','#7fcdbb','#1d91c0','#225ea8', '#41b6c4','#081d58')),labels=c("PTV", "Missense (all)", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=c(-0.1,-0.05,0,0.05,0.1), limits=c(-0.1,0.1)) + 
scale_y_continuous(limits = c(0,16), breaks = dat_plot_tmp_rt$rank_plot, labels = c("PTV", "Missense (all)", "Synonymous", "PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous", "PTV", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black",alpha=0.5) +
theme_classic() +
theme(legend.position = "NULL",axis.text.y=element_blank(),plot.title = element_text(size=10)) +
labs(y = "", x = expression(beta), title = "Reaction time") +
coord_cartesian(xlim=c(-0.05,0.1), clip = 'off') +
annotate("text", x=-0.05, y=15, label= dat_plot_tmp_edu$N_GENE[1], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=14, label= dat_plot_tmp_edu$N_GENE[2], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=13, label= dat_plot_tmp_edu$N_GENE[3], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=10, label= dat_plot_tmp_edu$N_GENE[4], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=9, label= dat_plot_tmp_edu$N_GENE[5], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=8, label= dat_plot_tmp_edu$N_GENE[6], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=7, label= dat_plot_tmp_edu$N_GENE[7], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=6, label= dat_plot_tmp_edu$N_GENE[8], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=3, label= dat_plot_tmp_edu$N_GENE[9], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=2, label= dat_plot_tmp_edu$N_GENE[10], hjust = 0, size=3) + 
annotate("text", x=-0.05, y=1, label= dat_plot_tmp_edu$N_GENE[11], hjust = 0, size=3) # + 

# Verbal-numerical reasoning
dat_plot_tmp_fiall <- dat_plot_tmp[which(dat_plot_tmp$Phenotype=="Verbal-numerical reasoning (baseline)"),]
dat_plot_tmp_fiall$rank_plot <- rev(c(1,2,3,6,7,8,9,10,13,14,15))
p3 <- ggplot(dat_plot_tmp_fiall, aes(y=rank_plot, x=BETA, color=Variant_category)) + 
geom_point(size=3) +
geom_errorbarh(aes(xmin=lower, xmax=upper), height=.3, size=0.6) +
scale_color_manual(values=rev(c('#c7e9b4','#7fcdbb','#1d91c0','#225ea8', '#41b6c4','#081d58')),labels=c("PTV", "Missense (all)", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous")) +
scale_x_continuous(breaks=c(-0.15,-0.1,-0.05,0,0.05), limits=c(-0.15,0.05)) + 
scale_y_continuous(limits = c(0,16), breaks = dat_plot_tmp_fiall$rank_plot, labels = c("PTV", "Missense (all)", "Synonymous", "PTV", "Missense (MPC > 3)", "Missense (3 >= MPC > 2)", "Missense (other)", "Synonymous", "PTV", "Missense (other)", "Synonymous")) + 
geom_vline(xintercept=0,linetype="dashed", color = "black",alpha=0.5) +
theme_classic() +
theme(legend.position = "NULL",axis.text.y=element_blank(),plot.title = element_text(size=10)) +
labs(y = "", x = expression(beta), title = "Verbal-numerical reasoning") +
coord_cartesian(xlim=c(-0.1,0.05), clip = 'off')

######################################################################
# Gene-based burden in EUR
######################################################################
assocfilepath <- "edu_baseline_irnt.ptv.maf00001.regenie.qc.txt"

gene_pos <- fread("UKB_gene_pos.txt",stringsAsFactors=FALSE)
assoc_raw <- fread(assocfilepath,stringsAsFactors=FALSE)
dat_plot_raw <- left_join(assoc_raw, gene_pos, by="GENE")

dim(dat_plot_raw[is.na(dat_plot_raw$CHR)==TRUE,])
dat_plot_raw <- dat_plot_raw[is.na(dat_plot_raw$CHR)==FALSE,]
dat_plot_raw$CHR[which(dat_plot_raw$CHR=="X")] <- 23 
dat_plot_raw$CHR <- as.numeric(dat_plot_raw$CHR)
dat_plot_raw$P_fdr <- p.adjust(dat_plot_raw$P, method = 'fdr')
dat_plot_raw <- dat_plot_raw[order(dat_plot_raw$P),]
dat_plot_raw[which(dat_plot_raw$P_fdr<0.05),]

# Manhattan plot
dat_plot <- as.data.frame(dat_plot_raw)
dat_plot <- dat_plot[with(dat_plot, order(CHR, BP)),]
N_GENE <- length(dat_plot[,1])
dat_plot$BPcum <- seq(1,N_GENE,1)
dat_plot$genomewide_annot <- NA 
dat_plot$genomewide_annot[which(dat_plot$GENE %in% c("ADGRB2","GIGYF1","KDM5B","SLC8A1","BCAS3"))] <- "YES"
dat_plot$fdr_annot <- NA 
dat_plot$fdr_annot[which(dat_plot$GENE %in% c("ANKRD12","NDUFA6","MAP1A"))] <- "YES"

axisdf = dat_plot %>% group_by(CHR) %>% summarize(center=( max(BPcum) + min(BPcum) ) / 2 )

p4 <- ggplot(dat_plot, aes(x=BPcum, y=-log10(P))) +
    # Add lines
    geom_hline(yintercept=-1*log10(0.05/N_GENE), linetype="dashed", color = "#d95f0e", size=0.6) + 
    # Show all points
    geom_point( aes(color=as.factor(CHR)), alpha=0.8, size=1.3) +
    scale_color_manual(values = rep(c("#1d91c0","#74c476"), 22 )) +
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=4, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=3, shape=17) +
    # Add label using ggrepel to avoid overlapping
    geom_text_repel(seed=5, data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], aes(label=GENE), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, fontface="italic") +
    geom_text_repel(seed=5, data=dat_plot[which(dat_plot$fdr_annot=="YES"),], aes(label=GENE), size=3, point.padding=0.6, segment.color="black", box.padding = 0.7, fontface="italic") +
    # Custom X axis:
    scale_x_continuous(name="", label=c("1","2","3","4","5","6","7","8","9","10","11","12","","14","15","16","17","18","19","20","","22","X"), breaks= axisdf$center) +
    scale_y_continuous(name=expression(-log[10](italic(P))), breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0)) +  # remove space between plot area and x axis
    # Custom the theme:
    theme_bw() +
    theme( 
      legend.position="none",
      panel.border = element_blank(),
      panel.grid.major.x = element_blank(),
      panel.grid.minor.x = element_blank(),
      plot.title = element_text(size=10),
      axis.line = element_line(colour="black")
    ) +
    labs(title="Educational attainment")

# QQ plot
dat_plot <- dat_plot[order(dat_plot$P),]
dat_plot$P_exp <- ppoints(length(dat_plot$P))
dat_plot$clower <- -log10(qbeta(p = (1 - 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))
dat_plot$cupper <- -log10(qbeta(p = (1 + 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))

obs_chisq <- format(round(median(qchisq(dat_plot$P,1)),3), trim=TRUE, digis=3, nsmall=3)
lambdagc <- format(round(median(qchisq(dat_plot$P,1))/0.455,3), trim=TRUE, digis=3, nsmall=3)
obs_chisq
lambdagc 

p7 <- ggplot(dat_plot, aes(x = -1*log10(P_exp), y=-1*log10(P))) + 
    # Add points
    geom_point() +  
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=3, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=2, shape=17) +
    # Add diagonal line
    geom_abline(intercept=0, slope=1, colour="gray20") + 
    # Add 95% CI
    geom_ribbon(mapping = aes(x = -1*log10(P_exp), ymin = clower, ymax = cupper), alpha = 0.1) +
    # Add significant line
    geom_abline(intercept= -1*log10(0.05/N_GENE), slope=0, linetype = "dashed", colour="#d95f0e") + 
    # Custom the theme:
    theme_bw() +
    theme( 
    legend.position="none",  
    axis.ticks = element_line(size = 0.5),
    panel.grid = element_blank(),
    plot.title = element_text(size=10),
    panel.border = element_blank(),
    axis.line = element_line(colour = "black")
    ) +
    scale_y_continuous(name="", breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0) ) +  # remove space between plot area and x axis
    geom_text(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, y = c(11,10,9,8,7), label = GENE, fontface="italic"), hjust = 1, size=3) +
    geom_segment(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, xend = -log10(P_exp), y = c(11,10,9,8,7), yend = -log10(P)), size = 0.1) +
    geom_text(data = dat_plot[which(dat_plot$fdr_annot=="YES"),], mapping = aes(x = 2, y = c(6,5,4), label = GENE, fontface="italic"), hjust = 1, size=3) +
    geom_segment(data = dat_plot[which(dat_plot$fdr_annot=="YES"),], mapping = aes(x = 2, xend = -log10(P_exp), y = c(6,5,4), yend = -log10(P)), size = 0.1) +
    labs(title="  ")
    
# RT ptv
assocfilepath <- "rt_baseline_irnt.model2.ptv456k.maf00001.regenie.qc.txt"

gene_pos <- fread("UKB_Freeze_456k_gene_pos.txt",stringsAsFactors=FALSE)
assoc_raw <- fread(assocfilepath,stringsAsFactors=FALSE)
dat_plot_raw <- left_join(assoc_raw, gene_pos, by="GENE")

dim(dat_plot_raw[is.na(dat_plot_raw$CHR)==TRUE,])
dat_plot_raw <- dat_plot_raw[is.na(dat_plot_raw$CHR)==FALSE,]
dat_plot_raw$CHR[which(dat_plot_raw$CHR=="X")] <- 23 
dat_plot_raw$CHR <- as.numeric(dat_plot_raw$CHR)
dat_plot_raw$P_fdr <- p.adjust(dat_plot_raw$P, method = 'fdr')
dat_plot_raw <- dat_plot_raw[order(dat_plot_raw$P),]
dat_plot_raw[which(dat_plot_raw$P_fdr<0.05),]

dat_plot_raw[which(dat_plot_raw$GENE %in% c("ADGRB2", "GIGYF1", "KDM5B", "SLC8A1", "BCAS3", "ANKRD12", "NDUFA6", "MAP1A"))]

# Manhattan plot
dat_plot <- as.data.frame(dat_plot_raw)
dat_plot <- dat_plot[with(dat_plot, order(CHR, BP)),]
N_GENE <- length(dat_plot[,1])
dat_plot$BPcum <- seq(1,N_GENE,1)
dat_plot$genomewide_annot <- NA 
dat_plot$genomewide_annot[which(dat_plot$GENE %in% c("KDM5B"))] <- "YES"
dat_plot$fdr_annot <- NA 
dat_plot$fdr_annot[which(dat_plot$GENE %in% c(""))] <- "YES"

axisdf = dat_plot %>% group_by(CHR) %>% summarize(center=( max(BPcum) + min(BPcum) ) / 2 )

p5 <- ggplot(dat_plot, aes(x=BPcum, y=-log10(P))) +
    # Show all points
    geom_point( aes(color=as.factor(CHR)), alpha=0.8, size=1.3) +
    scale_color_manual(values = rep(c("#1d91c0","#74c476"), 22 )) +
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=4, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=3, shape=17) +
    # Add label using ggrepel to avoid overlapping
    geom_text_repel(seed=3, data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], aes(label=GENE), size=4, point.padding=0.5, segment.color=NA, box.padding = 0.7, fontface="italic") +
    geom_text_repel(seed=3, data=dat_plot[which(dat_plot$fdr_annot=="YES"),], aes(label=GENE), size=3, point.padding=0.5, segment.color=NA, fontface="italic") +
    # Custom X axis:
    scale_x_continuous(name="", label = c("1","2","3","4","5","6","7","8","9","10","11","12","","14","15","16","17","18","19","20","","22","X"), breaks= axisdf$center) +
    scale_y_continuous(name=expression(-log[10](italic(P))), breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0) ) +  # remove space between plot area and x axis
    # Add lines
    geom_hline(yintercept=-1*log10(0.05/N_GENE), linetype="dashed", color = "#d95f0e", size=0.6) + 
    # Custom the theme:
    theme_bw() +
    theme( 
      legend.position="none",
      panel.border = element_blank(),
      panel.grid.major.x = element_blank(),
      panel.grid.minor.x = element_blank(),
      plot.title = element_text(size=10),
      axis.line = element_line(colour = "black")
    ) + 
    labs(title="Reaction time")

# QQ plot
dat_plot <- dat_plot[order(dat_plot$P),]
dat_plot$P_exp <- ppoints(length(dat_plot$P))
dat_plot$clower <- -log10(qbeta(p = (1 - 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))
dat_plot$cupper <- -log10(qbeta(p = (1 + 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))

p8 <- ggplot(dat_plot, aes(x = -1*log10(P_exp), y=-1*log10(P))) + 
    # Add points
    geom_point() +  
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=3, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=2, shape=17) +
    # Add diagonal line
    geom_abline(intercept=0, slope=1, colour="gray20") + 
    # Add 95% CI
    geom_ribbon(mapping = aes(x = -1*log10(P_exp), ymin = clower, ymax = cupper), alpha = 0.1) +
    # Add significant line
    geom_abline(intercept= -1*log10(0.05/N_GENE), slope=0, linetype = "dashed", colour="#d95f0e") + 
    # Custom the theme:
    theme_bw() +
    theme( 
    legend.position="none",  
    axis.ticks = element_line(size = 0.5),
    panel.grid = element_blank(),
    plot.title = element_text(size=10),
    panel.border = element_blank(),
    axis.line = element_line(colour = "black")
    ) +
    # Custom axis:
    scale_x_continuous(name="", breaks=seq(1,5,1), limits=c(0,max(-log10(dat_plot$P_exp))*1.03), expand = c(0, 0) ) +
    scale_y_continuous(name="", breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0) ) +  # remove space 

    geom_text(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, y = c(11), label = GENE, fontface="italic"), hjust = 1, size=3) +
    geom_segment(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, xend = -log10(P_exp), y = c(11), yend = -log10(P)), size = 0.1) +
    labs(title="  ")
    
# FIALL model 2 ptv
assocfilepath <- "fiall_baseline_irnt.model2.ptv456k.maf00001.regenie.qc.txt"
gene_pos <- fread("UKB_Freeze_456k_gene_pos.txt",stringsAsFactors=FALSE)

assoc_raw <- fread(assocfilepath,stringsAsFactors=FALSE)
dat_plot_raw <- left_join(assoc_raw, gene_pos, by="GENE")

dim(dat_plot_raw[is.na(dat_plot_raw$CHR)==TRUE,])
dat_plot_raw <- dat_plot_raw[is.na(dat_plot_raw$CHR)==FALSE,]
dat_plot_raw$CHR[which(dat_plot_raw$CHR=="X")] <- 23 
dat_plot_raw$CHR <- as.numeric(dat_plot_raw$CHR)
dat_plot_raw$P_fdr <- p.adjust(dat_plot_raw$P, method = 'fdr')
dat_plot_raw <- dat_plot_raw[order(dat_plot_raw$P),]
dat_plot_raw[which(dat_plot_raw$P_fdr<0.05),]

# Manhattan plot
dat_plot <- as.data.frame(dat_plot_raw)
dat_plot <- dat_plot[with(dat_plot, order(CHR, BP)),]
N_GENE <- length(dat_plot[,1])
dat_plot$BPcum <- seq(1,N_GENE,1)
dat_plot$genomewide_annot <- NA
dat_plot$genomewide_annot[which(dat_plot$GENE %in% c("ANKRD12", "KDM5B", "RC3H2", "CACNA1A"))] <- "YES"
dat_plot$fdr_annot <- NA
dat_plot$fdr_annot[which(dat_plot$GENE %in% c("ARHGEF7", "C11orf94", "KIF26A"))] <- "YES"

axisdf = dat_plot %>% group_by(CHR) %>% summarize(center=( max(BPcum) + min(BPcum) ) / 2 )

p6 <- ggplot(dat_plot, aes(x=BPcum, y=-log10(P))) +
    # Show all points
    geom_point( aes(color=as.factor(CHR)), alpha=0.8, size=1.3) +
    scale_color_manual(values = rep(c("#1d91c0","#74c476"), 22 )) +
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=4, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=3, shape=17) +
    # Add label using ggrepel to avoid overlapping
    geom_text_repel(seed=3, data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], aes(label=GENE), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7, fontface="italic") +
    geom_text_repel(seed=3, data=dat_plot[which(dat_plot$fdr_annot=="YES"),], aes(label=GENE), size=3, point.padding=0.6, segment.color="black", box.padding = 0.7, fontface="italic") +
    # Custom X axis:
    scale_x_continuous(name="Chromosome", label = c("1","2","3","4","5","6","7","8","9","10","11","12","","14","15","16","17","18","19","20","","22","X"), breaks= axisdf$center) +
     scale_y_continuous(name=expression(-log[10](italic(P))), breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0), ) +  # remove space between plot area and x axis
    # Add lines
    geom_hline(yintercept=-1*log10(0.05/N_GENE), linetype="dashed", color = "#d95f0e", size=0.6) + 
    # Custom the theme:
    theme_bw() +
    theme( 
      legend.position="none",
      panel.border = element_blank(),
      panel.grid.major.x = element_blank(),
      panel.grid.minor.x = element_blank(),
      plot.title = element_text(size=10),
      axis.line = element_line(colour = "black")
    ) +
    labs(title="Verbal-numerical reasoning")

# QQ plot
dat_plot <- dat_plot[order(dat_plot$P),]
dat_plot$P_exp <- ppoints(length(dat_plot$P))
dat_plot$clower <- -log10(qbeta(p = (1 - 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))
dat_plot$cupper <- -log10(qbeta(p = (1 + 0.95) / 2, shape1 = 1:N_GENE, shape2 = N_GENE:1))
obs_chisq <- format(round(median(qchisq(dat_plot$P,1)),3), trim=TRUE, digis=3, nsmall=3)
lambdagc <- format(round(median(qchisq(dat_plot$P,1))/0.455,3), trim=TRUE, digis=3, nsmall=3)
obs_chisq
lambdagc 

p9 <- ggplot(dat_plot, aes(x = -1*log10(P_exp), y=-1*log10(P))) + 
    # Add points
    geom_point() +  
    # Annotate points
    geom_point(data=dat_plot[which(dat_plot$genomewide_annot=="YES"),], color="purple", size=3, shape=17) +
    geom_point(data=dat_plot[which(dat_plot$fdr_annot=="YES"),], color="#fe9929", size=2, shape=17) +
    # Add diagonal line
    geom_abline(intercept=0, slope=1, colour="gray20") + 
    # Add 95% CI
    geom_ribbon(mapping = aes(x = -1*log10(P_exp), ymin = clower, ymax = cupper), alpha = 0.1) +
    # Add significant line
    geom_abline(intercept= -1*log10(0.05/N_GENE), slope=0, linetype = "dashed", colour="#d95f0e") + 
    # Custom the theme:
    theme_bw() +
    theme( 
    legend.position="none",  
    axis.ticks = element_line(size = 0.5),
    panel.grid = element_blank(), 
    plot.title = element_text(size=10), 
    panel.border = element_blank(),
    axis.line = element_line(colour = "black")
    ) +
    scale_x_continuous(name=expression(Expected ~ ~-log[10](italic(p))), breaks=seq(1,5,1), limits=c(0,max(-log10(dat_plot$P_exp))*1.03), expand = c(0, 0) ) +
    scale_y_continuous(name="", breaks=seq(1,12,2), limits=c(0,12), expand = c(0, 0) ) +  # remove space 
    geom_text(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, y = c(11,10,9,8), label = GENE, fontface="italic"), hjust = 1, size=3) +
    geom_segment(data = dat_plot[which(dat_plot$genomewide_annot=="YES"),], mapping = aes(x = 2, xend = -log10(P_exp), y = c(11,10,9,8), yend = -log10(P)), size = 0.1) +
    geom_text(data = dat_plot[which(dat_plot$fdr_annot=="YES"),], mapping = aes(x = 2, y = c(7,6,5), label = GENE, fontface="italic"), hjust = 1, size=3) +
    geom_segment(data = dat_plot[which(dat_plot$fdr_annot=="YES"),], mapping = aes(x = 2, xend = -log10(P_exp), y = c(7,6,5), yend = -log10(P)), size = 0.1) +
    labs(title="  ")

#===========================================================
# output results
#===========================================================
ggarrange(ggarrange(p1,p2,p3,widths=c(1.5,1,1),heights=c(1),nrow=1,ncol=3,labels=c("a","","")),
ggarrange(p4,p7,widths=c(2,1),heights=c(1),nrow=1,ncol=2,labels=c("b","c")),
ggarrange(p5,p8,widths=c(2,1),heights=c(1),nrow=1,ncol=2,labels=c("d","e")),
ggarrange(p6,p9,widths=c(2,1),heights=c(1),nrow=1,ncol=2,labels=c("f","g")),widths=c(1),heights=c(1.2,1,1,1),nrow=4,ncol=1)
#10x10inch

assocfilepath <- "edu_baseline_irnt.model2.ptv456k.maf00001.regenie.qc.v2.txt"
assocfilepath <- "rt_baseline_irnt.model2.ptv456k.maf00001.regenie.qc.txt"
assocfilepath <- "fiall_baseline_irnt.model2.ptv456k.maf00001.regenie.qc.txt"

gene_pos <- fread("UKB_Freeze_456k_gene_pos.txt",stringsAsFactors=FALSE)
assoc_raw <- fread(assocfilepath,stringsAsFactors=FALSE)
dat_plot_raw <- left_join(assoc_raw, gene_pos, by="GENE")

dim(dat_plot_raw[is.na(dat_plot_raw$CHR)==TRUE,])
dat_plot_raw <- dat_plot_raw[is.na(dat_plot_raw$CHR)==FALSE,]
dat_plot_raw$CHR[which(dat_plot_raw$CHR=="X")] <- 23 
dat_plot_raw$CHR <- as.numeric(dat_plot_raw$CHR)
dat_plot_raw$P_fdr <- p.adjust(dat_plot_raw$P, method = 'fdr')
dat_plot_raw <- dat_plot_raw[order(dat_plot_raw$P),]

dat_plot_raw[which(dat_plot_raw$GENE %in% c("ADGRB2", "GIGYF1", "KDM5B", "SLC8A1", "BCAS3", "ANKRD12", "NDUFA6", "MAP1A", "RC3H2", "CACNA1A", "ARHGEF7", "C11orf94", "KIF26A")),]

