#===========================================================
# KDM5B
#===========================================================
#-------------------
# format PTV carriers
#-------------------
library(data.table)

irnt <- function(x, k=3/8, randomties=FALSE, seed=NULL){
    if (randomties == FALSE){
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep")-k)/(sum(!is.na(x))+1-(2*k))))
    }else if (randomties == TRUE) {
        # Modified from Pain et al. Eur J Hum Genet 2018
        set.seed(seed)
        return(qnorm((rank(x,na.last="keep",ties.method='random')-k)/(sum(!is.na(x))+1-(2*k))))
    }
}

ptv_raw <- fread("KDM5B_lof_carriers.txt")
ptv_raw <- ptv_raw[which(ptv_raw$alt_af<0.00001),]

output_raw <- c()
for (i in 1:length(ptv_raw$gene)){
    tmp_carriers <- ptv_raw$carriers[i]
    tmp_carriers_df <- as.data.frame(matrix(unlist(tstrsplit(unlist(tstrsplit(tmp_carriers, ",")),":")),ncol=2))
    tmp_carriers_df$V1 <- as.character(tmp_carriers_df$V1)
    tmp_carriers_df$V2 <- as.numeric(as.character(tmp_carriers_df$V2))
    tmp_carriers_df <- tmp_carriers_df[order(tmp_carriers_df$V2, decreasing=TRUE),]
    tmp_carriers_df <- tmp_carriers_df[which(duplicated(tmp_carriers_df$V1)==FALSE),]
    colnames(tmp_carriers_df) <- c("Carrier","PTVcount")
    tmp_carriers_df$gene <- "KDM5B"
    tmp_output <- merge(ptv_raw[i,c("gene","chrom","pos","ref","alt","min_ref","min_alt","variant_id","vcf_variant_id","type","aa","alt_af")], tmp_carriers_df,by="gene",all.y=TRUE)
    output_raw <- rbind(output_raw,tmp_output)
}

#-------------------
# extract cog phenotype 
#-------------------
pheno_raw <- fread("/MYPATH/MYFILE.EUR.txt")

edu_baseline.lm <- lm(edu_baseline~sex+edu_baseline_age_mean0+edu_baseline_age_mean02+edu_baseline_age_mean0_sex+edu_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=pheno_raw)
pheno_raw$edu_baseline_resid[is.na(pheno_raw$edu_baseline)==FALSE] <- residuals(edu_baseline.lm)
pheno_raw$edu_baseline_resid_irnt[is.na(pheno_raw$edu_baseline)==FALSE] <- irnt(residuals(edu_baseline.lm))

fiall_baseline.lm <- lm(fiall_baseline~sex+fiall_baseline_age_mean0+fiall_baseline_age_mean02+fiall_baseline_age_mean0_sex+fiall_baseline_age_mean02_sex+PC1+PC2+PC3+PC4+PC5+PC6+PC7+PC8+PC9+PC10+PC11+PC12+PC13+PC14+PC15+PC16+PC17+PC18+PC19+PC20+assess_center10003+assess_center11001+assess_center11002+assess_center11003+assess_center11004+assess_center11005+assess_center11006+assess_center11007+assess_center11008+assess_center11009+assess_center11011+assess_center11012+assess_center11013+assess_center11014+assess_center11016+assess_center11017+assess_center11018+assess_center11020+assess_center11021+assess_center11022+assess_center11023, data=pheno_raw)
pheno_raw$fiall_baseline_resid[is.na(pheno_raw$fiall_baseline)==FALSE] <- residuals(fiall_baseline.lm)
pheno_raw$fiall_baseline_resid_irnt[is.na(pheno_raw$fiall_baseline)==FALSE] <- irnt(residuals(fiall_baseline.lm))

ptv_pheno_raw <- merge(output_raw,pheno_raw,by.x="Carrier",by.y="IID",all=FALSE)
summary(ptv_pheno_raw)
ptv_pheno_raw <- as.data.frame(ptv_pheno_raw)

#-------------------
# extract ICD code
#-------------------
icd10_raw <- as.data.frame(fread("/MYPATH/all_ICD10_20200901.pheno.v2.tsv.gz"))
icdlist <- names(icd10_raw)[2:length(names(icd10_raw))]

ptv_pheno_icd_raw <- merge(ptv_pheno_raw, icd10_raw, by.x="f_eid", by.y="IND", all=FALSE)

icd_count <- as.data.frame(colSums(ptv_pheno_icd_raw[,icdlist]))
icd_count$icd10 <- rownames(icd_count)
colnames(icd_count) <- c("count","icd10")

icd_count_neuropsych <- icd_count[which(icd_count$icd10 %in% c("F059", "F100", "F101", "F102", "F171", "F200", "F209", "F310", "F319", "F329", "F339", "F402", "F410", "F412", "F419", "F430", "F99", "G20", "G253", "G258", "G409", "G439", "G442", "G459", "G473", "G500", "G551", "G562", "G571", "G589", "G590", "G629", "G632", "G930", "G931", "G990")),]

icd_map <- as.data.frame(fread("/MYPATH/phewas_pheno_key.csv",header=FALSE))
colnames(icd_map) <- c("icd10","icd10_fullname")

icd_count_neuropsych_longname <- merge(icd_count_neuropsych, icd_map, by="icd10", all.x=TRUE)

fwrite(icd_count_neuropsych_longname, "KDM5B_lof_carriers.neuropsych_count.csv")
fwrite(ptv_pheno_icd_raw, "KDM5B_lof_carriers.cogphenosescovaricd10.csv")

#-------------------
# Make plot
#-------------------
library(data.table)
library(ggrepel)
library(ggplot2)
icd_count_neuropsych_longname <- fread("/MYPATH/KDM5B_lof_carriers.neuropsych_count.csv")
ptv_pheno_icd_raw <- fread("/MYPATH/KDM5B_lof_carriers.cogphenosescovaricd10.csv")

# exons in canonical
exon_pos <- rbind(c("27", "202729036", "202729173"),
c("26", "202729707", "202730027"),
c("25", "202730909", "202731063"),
c("24", "202731828", "202731939"),
c("23", "202733401", "202733886"),
c("22", "202735429", "202735587"),
c("21", "202736213", "202736392"),
c("20", "202740674", "202740812"),
c("19", "202741367", "202741722"),
c("18", "202742391", "202742505"),
c("17", "202742655", "202742805"),
c("16", "202745858", "202745982"),
c("15", "202746142", "202746323"),
c("14", "202748945", "202749139"),
c("13", "202750659", "202750778"),
c("12", "202752905", "202753067"),
c("11", "202755271", "202755452"),
c("10", "202756358", "202756516"),
c("9", "202758391", "202758510"),
c("8", "202760415", "202760573"),
c("7", "202762699", "202762808"),
c("6", "202764049", "202764145"),
c("5", "202766926", "202767060"),
c("4", "202773118", "202773288"),
c("3", "202774613", "202774735"),
c("2", "202777017", "202777094"),
c("1", "202808102", "202808305"))

exon_pos <- as.data.frame(exon_pos)
colnames(exon_pos) <- c("exon","start","end")
exon_pos$exon <- as.numeric(as.character(exon_pos$exon))
exon_pos$start <- as.numeric(as.character(exon_pos$start))
exon_pos$end <- as.numeric(as.character(exon_pos$end))
exon_pos$median <- (exon_pos$start + exon_pos$end)/2
exon_pos$exon_annot_odd <- rev(c(1, NA, 3, NA, 5, NA, 7, NA, 9, NA, 11, NA, 13, NA, 15, NA, 17, NA, NA, NA, 21, NA, 23, NA, NA, NA, 27))
exon_pos$exon_annot_even <- rev(c(NA, 2, NA, 4, NA, 6, NA, 8, NA, 10, NA, 12, NA, 14, NA, 16, NA, NA, NA, 20, NA, 22, NA, 24, NA, NA, NA))

dat_plot <- as.data.frame(ptv_pheno_icd_raw)
dat_plot.edu <- dat_plot[,c("f_eid","pos","edu_baseline_resid_irnt")]
colnames(dat_plot.edu) <- c("f_eid","pos","pheno")
dat_plot.fiall <- dat_plot[,c("f_eid","pos","fiall_baseline_resid_irnt")]
colnames(dat_plot.fiall) <- c("f_eid","pos","pheno")
dat_plot.edu$pheno_group <- "edu"
dat_plot.fiall$pheno_group <- "fiall"
dat_plot <- rbind(dat_plot.edu,dat_plot.fiall)

dat_plot$annot <- "NO"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F402==1),f_eid]),"annot"] <- "Anxiety and stress-related disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F410==1),f_eid]),"annot"] <- "Anxiety and stress-related disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F412==1),f_eid]),"annot"] <- "Anxiety and stress-related disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F419==1),f_eid]),"annot"] <- "Anxiety and stress-related disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F430==1),f_eid]),"annot"] <- "Anxiety and stress-related disorders"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F100==1),f_eid]),"annot"] <- "Substance use disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F101==1),f_eid]),"annot"] <- "Substance use disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F102==1),f_eid]),"annot"] <- "Substance use disorders"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F171==1),f_eid]),"annot"] <- "Substance use disorders"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F310==1),f_eid]),"annot"] <- "Bipolar disorder"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F319==1),f_eid]),"annot"] <- "Bipolar disorder"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F329==1),f_eid]),"annot"] <- "Depression"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F339==1),f_eid]),"annot"] <- "Depression"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F200==1),f_eid]),"annot"] <- "Schizophrenia"
dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$F209==1),f_eid]),"annot"] <- "Schizophrenia"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$G20==1),f_eid]),"annot"] <- "Parkinson's disease"

dat_plot[which(dat_plot$f_eid %in% ptv_pheno_icd_raw[which(ptv_pheno_icd_raw$G409==1),f_eid]),"annot"] <- "Epilepsy"

dat_plot[which(dat_plot$pos=="202762722"),"annot"] <- "p.Arg299Ter"

dat_plot$annot <- factor(dat_plot$annot, levels=c("NO", "p.Arg299Ter", "Parkinson's disease", "Epilepsy", "Schizophrenia", "Depression", "Bipolar disorder", "Substance use disorders", "Anxiety and stress-related disorders"))

head(dat_plot)
summary(dat_plot$annot)

dat_plot_edu_reduced <- dat_plot[which(dat_plot$pheno_group=="edu" & (dat_plot$annot=="NO" | dat_plot$annot=="p.Arg299Ter")),]

p1 <- ggplot(dat_plot_edu_reduced) + 
    geom_point(aes(x=pos, y=pheno, shape=annot, size=annot), color="#0570b0") +
    geom_line(aes(x=pos, y=pheno), stat = 'smooth', method='loess', formula = 'y ~ x', alpha=1, color="#0570b0") +
    geom_ribbon(aes(x=pos, y=pheno),stat='smooth', method = "loess", se=TRUE, alpha=0.1, formula = 'y ~ x',color=NA) +
    geom_hline(yintercept=0, linetype="dashed", color = "black", size=0.6) + 
    theme_classic() +
    scale_shape_manual(name="", values=c(16,18), labels=c("Not pathogenic/\nlikely pathogenic in Clinvar\n", "Intellectual disability\n(OMIM #618109)")) +
    scale_size_manual(name="", values=c(2,5), labels=c("Not pathogenic/\nlikely pathogenic in Clinvar\n", "Intellectual disability\n(OMIM #618109)")) +
    labs(x="Chromosome 1 position", y="Educational attainment")+
    theme(legend.position=c(0.78,0.7),legend.text = element_text(color="black",size=14),legend.title = element_blank(), axis.text.y=element_text(size=14),axis.text.x=element_text(size=14), axis.title.y=element_text(size=14),axis.title.x=element_text(size=14),legend.background = element_rect(colour = 'black', fill = 'white', linetype='solid')) +
    scale_y_continuous(breaks=c(-3,-2,-1,0,1,2,3), limits=c(-4,4.2))

for (i in 1:27){
    p1 <- p1 +	
        geom_segment(x = exon_pos[which(exon_pos$exon==i),"median"], y = 3.5, xend = exon_pos[which(exon_pos$exon==i),"median"], yend = 3.7,color="black") +
        annotate(geom="text", x=exon_pos[which(exon_pos$exon==i),"median"], y=3.9, label=exon_pos[which(exon_pos$exon==i),"exon_annot_odd"], color="black",size=4) +
        annotate(geom="text", x=exon_pos[which(exon_pos$exon==i),"median"], y=4.2, label=exon_pos[which(exon_pos$exon==i),"exon_annot_even"], color="black",size=4)
}
p1 <- p1 + geom_segment(x = exon_pos[which(exon_pos$exon==1),"median"], y = 3.6, xend = exon_pos[which(exon_pos$exon==27),"median"], yend = 3.6,color="black")

p1
