#===========================================================
# PheWAS Figures
# Extended Data Figure 1
# Supplementary Figure 3
#===========================================================
# library(RColorBrewer)
# n <- 26
# qual_col_pals = brewer.pal.info[brewer.pal.info$category == 'qual',]
# col_vector = unlist(mapply(brewer.pal, qual_col_pals$maxcolors, rownames(qual_col_pals)))
# set.seed(3)
# pie(rep(1,n), col=sample(col_vector, n))

# https://medialab.github.io/iwanthue/

library(icd.data)
library(ggplot2)
library(ggrepel)
library(dplyr)

get_icd10_chapter <- function(icd_code){
  my_letters <- toupper(letters[1:26])
  first_letter <- which(my_letters == substr(icd_code,1,1))
  first_number <- as.integer(substr(icd_code,2,3))
  if(first_letter == 21){
    ch_name <- "ICD10: Codes for special purposes"
    return(ch_name)
  }
  for(i in 1:length(icd10_chapters)){
    ch_name <- paste("ICD10",names(icd10_chapters[i]))
    ch <- data.frame(icd10_chapters[i])
    start <- ch[,1][1]
    stop <- ch[,1][2]
    start_letter <- which(my_letters == substr(start,1,1))
    start_number <- as.integer(substr(start,2,3))
    stop_letter <- which(my_letters == substr(stop,1,1))
    stop_number <- as.integer(substr(stop,2,3))
    if(start == "F01"){
      start_number = 0
    }
    if(stop == "T88"){
      stop_number <- 99
    }
    if(stop == "O9A"){
      stop_number <- 99
    }
    # letter is completly in between start and stop
    if(first_letter >= start_letter && first_letter <= stop_letter){
      return(ch_name)
    }
    # first letter completely matches start and stop letters, number is in between
    if(first_letter == start_letter && first_letter == stop_letter){
      if(first_number >= start_number && first_number <= stop_number){
        return(ch_name)
      }
    }
    # first letter matches start, number greater than start, first letter does not match stop
    if(first_letter == start_letter && first_letter != stop_letter){
      if(first_number >= start_number){
        return(ch_name)
      }
    }
    # first_letter does not match start, first letter matches stop, number less than stop
    if(first_letter != start_letter && first_letter == stop_letter){
      if(first_number <= stop_number){
        return(ch_name)
      }
    }
  }
  return("ICD10_not_found")
}

do_genes <- c("KDM5B", "ADGRB2", "GIGYF1", "ANKRD12", "SLC8A1", "CACNA1A", "RC3H2", "BCAS3")
for(gene_idx in do_genes){
  gene_idx=do_genes[i]
  print(gene_idx)
  var_info <- read.csv("Data_Dictionary_Showcase.csv")
  var_levels <- strsplit(as.character(var_info$Path)," > ")
  auto_cats <- read.csv("phewas_pheno_categories.v2.csv")
  dat_raw <- read.csv(paste0("/MYPATH/phewas.maf00001.",GENE,".v1.csv"), stringsAsFactors=FALSE)
  phewas <- dat_raw[which(dat_raw$gene==gene_idx),]  

  # get categories
  categories <- data.frame()
  unmatched <- c()
  for(i in 1:nrow(phewas)){
    pheno <- as.character(phewas$pheno[i])
    # f.n.0.0
    if(strsplit(pheno,"\\.")[[1]][1] == "f"){
      field_id <- strsplit(pheno,"\\.")[[1]][2]
      if(field_id %in% var_info$FieldID){
        all_levels <- var_levels[which(var_info$FieldID == field_id)][[1]]
        if(length(all_levels) == 2){
          categ <- as.character(var_levels[which(var_info$FieldID == field_id)][[1]][2])
        }
        if(length(all_levels) > 2){
          categ <- as.character(var_levels[which(var_info$FieldID == field_id)][[1]][2])
        }
        categories <- rbind(categories,data.frame(pheno,categ))
        next()
      }
      else{
        next()
      }
    }
    if(strsplit(pheno,"_")[[1]][1] == "FH"){
      categ <- "Family history"
      categories <- rbind(categories,data.frame(pheno,categ))
      next()
    }
    if(pheno %in% auto_cats$pheno){
      categ <- as.character(auto_cats$category[which(auto_cats$pheno == pheno)])
      if(categ == "ICD10"){
        # get chapter
        categ <- get_icd10_chapter(pheno)
      }
      categories <- rbind(categories,data.frame(pheno,categ))
      next()
    }
    categ <- "Composite phenotypes"
    categories <- rbind(categories,data.frame(pheno,categ))
    unmatched <- append(unmatched,pheno)
  }
  categories$pheno <-  as.character(categories$pheno) 
  categories$categ <-  as.character(categories$categ) 
  biomarker <- c("f_30000_0_0", "f_30010_0_0", "f_30020_0_0", "f_30030_0_0", "f_30040_0_0", "f_30050_0_0", "f_30060_0_0", "f_30070_0_0", "f_30080_0_0", "f_30090_0_0", "f_30100_0_0", "f_30110_0_0", "f_30120_0_0", "f_30130_0_0", "f_30140_0_0", "f_30150_0_0", "f_30160_0_0", "f_30170_0_0", "f_30180_0_0", "f_30190_0_0", "f_30200_0_0", "f_30210_0_0", "f_30220_0_0", "f_30240_0_0", "f_30250_0_0", "f_30260_0_0", "f_30270_0_0", "f_30280_0_0", "f_30290_0_0", "f_30300_0_0", "f_30500_0_0", "f_30510_0_0", "f_30520_0_0", "f_30530_0_0", "f_30600_0_0","f_30610_0_0", "f_30620_0_0", "f_30630_0_0", "f_30640_0_0", "f_30650_0_0", "f_30660_0_0", "f_30670_0_0", "f_30680_0_0", "f_30690_0_0", "f_30700_0_0", "f_30710_0_0", "f_30720_0_0", "f_30730_0_0", "f_30740_0_0", "f_30750_0_0", "f_30760_0_0", "f_30770_0_0", "f_30780_0_0", "f_30790_0_0", "f_30800_0_0", "f_30810_0_0", "f_30820_0_0", "f_30830_0_0", "f_30840_0_0", "f_30850_0_0", "f_30860_0_0", "f_30870_0_0", "f_30880_0_0", "f_30890_0_0")
  categories[which(categories$pheno %in% biomarker),"categ"] <- "Biomarker"
  summary(factor(categories$categ))
  
  phewas_cat <- merge(categories,phewas,by = "pheno")
  phewas <- phewas_cat[with(phewas_cat,order(categ,long_pheno)),]
  phewas$categ_factor <- factor(phewas$categ)
  categs <- levels(phewas$categ_factor)

  phewas_plot <- phewas[is.na(phewas$p)==FALSE,]
  phewas_plot$log10p <- -log10(phewas_plot$p)
  phewas_plot$log10p[which(phewas_plot$log10p==Inf)] <- 300
  ntest <- length(phewas_plot$log10p)

  phewas_plot[which(phewas_plot$log10p>5),]
  phewas_plot[which(phewas_plot$p < 0.05/ntest),]
  
  phewas_plot$log10p_plot <- phewas_plot$log10p
  phewas_plot$log10p_plot[which(phewas_plot$log10p>30)] <- 30
  ymax <- max(phewas_plot$log10p_plot)
  phewas_plot$rank <- seq(1,ntest,1)
  phewas_plot$sig_annot <- "NO"
  phewas_plot[which(phewas_plot$log10p_plot > -1*log10(0.05/ntest)),"sig_annot"] <- "YES"
  phewas_plot$sig_annot_label <- "NO"
  phewas_plot[which(phewas_plot$log10p_plot > -1*log10(0.05/ntest)),"sig_annot_label"] <- "YES"

  axisdf = phewas_plot %>% group_by(categ_factor) %>% summarize(center=( max(rank) + min(rank) ) / 2 )

p1 <- ggplot(phewas_plot, aes(x=rank, y=log10p_plot)) +
  # Show all points
  geom_point( aes(color=categ_factor), alpha=0.8, size=1.3) +
  # scale_color_manual(values = rep(c("#1d91c0","#74c476"), length(categs))) +
  scale_color_manual(values = c("#9a97e2","#87bb37","#a25bcc","#54c45a","#d053b5","#549231","#606ad7","#b9ae39","#516fb1","#db9435","#4cb0d9","#dd5730","#55c8b2","#cd4281","#67c07e","#d6445c","#438a4d","#93518f","#677328","#de89be","#2a6a45","#ad4c2b","#38977f","#b45e67","#acae67","#e1956f","#91692d") )+
  # Add lines
  geom_hline(yintercept=-1*log10(0.05/ntest), linetype="dashed", color = "#d95f0e", size=1) + 
  # Annotate points
  geom_point(data=phewas_plot[which(phewas_plot$sig_annot=="YES"),], color="#e34a33", size=4, shape=17) +
  # Add label using ggrepel to avoid overlapping
  geom_text_repel(seed=5, data=phewas_plot[which(phewas_plot$sig_annot=="YES"),], aes(label=long_pheno), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7) +
  # Custom X axis:
  scale_x_continuous(name="Phenotypes", label = axisdf$categ_factor, breaks= axisdf$center) +
  scale_y_continuous(name=expression(-log[10](italic(P))), breaks=seq(1,10,1), limits=c(0,10), expand = c(0, 0) ) +  # remove space between plot area and x axis
  # Custom the theme:
  theme_bw() +
  theme( 
    legend.position="none",
    panel.border = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    axis.text.x = element_blank()
  )
p1
write.csv(phewas_plot,paste0("phewas_plot_",gene_idx,".csv"))
}

#===========================================================
# effect size distribution from PheWAS
# Supplementary Figure 3
#===========================================================
library(data.table)
library(icd.data)
library(ggplot2)
library(ggrepel)
library(dplyr)
dat <- fread("UKBB_cogexome.SupplTable7.csv",stringsAsFactor=FALSE,data.table=FALSE)
str(dat)
table(dat$Gene)
dat$Phenotype_category_short <- NA
dat[which(dat$`Phenotype category`=="Biomarker"), "Phenotype_category_short"] <- "Biomarker"
dat[which(dat$`Phenotype category`=="Composite phenotypes"), "Phenotype_category_short"] <- "Composite phenotypes"
dat[which(dat$`Phenotype category`=="Family history"), "Phenotype_category_short"] <- "Family history"
dat[which(dat$`Phenotype category`=="ICD10 cause of death"), "Phenotype_category_short"] <- "Cause of death"
dat[which(dat$`Phenotype category`=="ICD10 Congenital malformations, deformations and chromosomal abnormalities"), "Phenotype_category_short"] <- "ICD10 Congenital"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the circulatory system"), "Phenotype_category_short"] <- "ICD10 circulatory"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the digestive system"), "Phenotype_category_short"] <- "ICD10 digestive"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the eye and adnexa"), "Phenotype_category_short"] <- "ICD10 eye"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the genitourinary system"), "Phenotype_category_short"] <- "ICD10 genitourinary"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the musculoskeletal system and connective tissue"), "Phenotype_category_short"] <- "ICD10 musculoskeletal"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the nervous system"), "Phenotype_category_short"] <- "ICD10 nerve"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the respiratory system"), "Phenotype_category_short"] <- "ICD10 respiratory"
dat[which(dat$`Phenotype category`=="ICD10 Diseases of the skin and subcutaneous tissue"), "Phenotype_category_short"] <- "ICD10 skin"
dat[which(dat$`Phenotype category`=="ICD10 Endocrine, nutritional and metabolic diseases"), "Phenotype_category_short"] <- "ICD10 metabolic"
dat[which(dat$`Phenotype category`=="ICD10 Mental, Behavioral and Neurodevelopmental disorders"), "Phenotype_category_short"] <- "ICD10 mental"
dat[which(dat$`Phenotype category`=="ICD10 Neoplasms"), "Phenotype_category_short"] <- "ICD10 neoplasms"
dat[which(dat$`Phenotype category`=="ICD10 Pregnancy, childbirth and the puerperium"), "Phenotype_category_short"] <- "ICD10 reproductive"
dat[which(dat$`Phenotype category`=="ICD10 Symptoms, signs and abnormal clinical and laboratory findings, not elsewhere classified"), "Phenotype_category_short"] <- "ICD10 symptoms"
dat[which(dat$`Phenotype category`=="Operation code"), "Phenotype_category_short"] <- "Operations"
dat[which(dat$`Phenotype category`=="Self reported illness: cancer"), "Phenotype_category_short"] <- "Self-reported cancer"
dat[which(dat$`Phenotype category`=="Self reported illness: non-cancer"), "Phenotype_category_short"] <- "Self-reported non-cancer diseases"
dat[which(dat$`Phenotype category`=="Self reported medication"), "Phenotype_category_short"] <- "Self-reported medication"

genelist <- c("ADGRB2", "ANKRD12", "BCAS3", "CACNA1A", "GIGYF1", "KDM5B", "RC3H2", "SLC8A1")
testnumberlist <- c(3102, 3146, 3102, 2972, 3147, 3138, 2970, 3143)

# 1,2,3,5,6,8
for (i in 1:8){
phewas <- dat[which(dat$Gene==genelist[i] & dat$`P-value`<0.0001),]
phewas <- phewas[with(phewas,order(Phenotype_category_short,Phenotype)),]
phewas$categ_factor <- factor(phewas$Phenotype_category_short)
categs <- levels(phewas$categ_factor)

phewas_plot <- phewas[is.na(phewas$`P-value`)==FALSE,]
phewas_plot$log10p <- -log10(phewas_plot$`P-value`)
phewas_plot$log10p[which(phewas_plot$log10p==Inf)] <- 300
ntest <- length(phewas_plot$`P-value`)

phewas_plot$log10p_plot <- phewas_plot$log10p
phewas_plot$log10p_plot[which(phewas_plot$log10p>30)] <- 30
ymax <- max(phewas_plot$BETA)
phewas_plot$rank <- seq(1,ntest,1)
phewas_plot$sig_annot <- "NO"
phewas_plot[which(phewas_plot$log10p_plot > -1*log10(0.05/testnumberlist[i])),"sig_annot"] <- "YES"
phewas_plot$sig_annot_label <- "NO"
phewas_plot[which(phewas_plot$log10p_plot > -1*log10(0.05/testnumberlist[i])),"sig_annot_label"] <- "YES"

axisdf = phewas_plot %>% group_by(categ_factor) %>% summarize(center=( max(rank) + min(rank) ) / 2 )

phewas_plot$categ_label <- phewas_plot$Phenotype_category_short

str(phewas_plot)
phewas_plot <- phewas_plot[which(phewas_plot$`Phenotype category`!="Biomarker" &phewas_plot$`Phenotype category`!= "Composite phenotypes"),]

p1 <- ggplot(phewas_plot, aes(x=rank, y=BETA)) +
# Show all points
geom_point(alpha=0.8, size=1.3) +
scale_color_manual(values = c("#9a97e2","#87bb37","#a25bcc","#54c45a","#d053b5","#549231","#606ad7","#b9ae39","#516fb1","#db9435","#4cb0d9","#dd5730","#55c8b2","#cd4281","#67c07e","#d6445c","#438a4d","#93518f","#677328","#de89be","#2a6a45","#ad4c2b","#38977f","#b45e67","#acae67","#e1956f","#91692d") )+
# Annotate points
geom_point(data=phewas_plot[which(phewas_plot$sig_annot=="YES"),], color="#e34a33", size=4, shape=17) +
# Add label using ggrepel to avoid overlapping
geom_text_repel(seed=5, data=phewas_plot[which(phewas_plot$sig_annot=="YES"),], aes(label=Phenotype), size=4, point.padding=0.5, segment.color="black", box.padding = 0.7) +
geom_segment(x=-2.25, xend=-1.75, y=0.307, yend=0.307, color="red") + 
# Custom X axis:
scale_x_continuous(name="Phenotypes", label = phewas_plot$categ_label, breaks = phewas_plot$rank, limits = c(min(phewas_plot$rank), max(phewas_plot$rank))) +
scale_y_continuous(name="BETA", limits = c(0, 7)) +
# Custom the theme:
theme_bw() +
theme( 
panel.border = element_blank(),
panel.grid.major.x = element_blank(),
panel.grid.minor.x = element_blank(),
axis.text.x = element_text(angle = 60, vjust = 1, hjust=1, size = 10),
) + 
labs(title=substitute(italic(x), list(x=genelist[i]))) 

pdf(paste0("phewas_",genelist[i],"_BETA.v1.pdf"),width=10,height=6)
p1
dev.off()
}