library(data.table)
chrom <- commandArgs(trailingOnly = TRUE)[1]

annot <- fread(paste0("/MYPATH/chr",chrom,".UKB.sites.CADDMPC.txt"),sep=" ")
carrier <- fread(paste0("/MYPATH/UKB_MODERATE_IMPACT_CARRIERS/chr",chrom,"_MODERATE_carriers.txt.gz"))
annot$SIFT <- factor(annot$SIFT)
annot$PolyPhen <- factor(annot$PolyPhen)
annot$MPC_class1 <- cut(annot$MPC, breaks=c(0,2,3,max(annot$MPC,na.rm=TRUE)), labels=c("mpc0","mpc2","mpc3"), include.lowest=TRUE)
annot$MPC_class2 <- cut(annot$MPC, breaks=c(0,1,2,max(annot$MPC,na.rm=TRUE)), labels=c("mpc0","mpc1","mpc2"), include.lowest=TRUE)
annot$CADD_class20 <- cut(annot$CADD_PHRED, breaks=c(0,20,max(annot$CADD_PHRED,na.rm=TRUE)), labels=c("cadd0","cadd20"), include.lowest=TRUE)
annot$CADD_class30 <- cut(annot$CADD_PHRED, breaks=c(0,20,30,max(annot$CADD_PHRED,na.rm=TRUE)), labels=c("cadd0","cadd20","cadd30"),include.lowest=TRUE)

# cross check MPC grouping with CADD, SIFT, PolyPhen
tab1 <- table(annot$MPC_class1, annot$CADD_class20, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class2, annot$CADD_class20, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class1, annot$CADD_class30, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class2, annot$CADD_class30, useNA="always")
tab1
prop.table(tab1, margin = 1)


tab1 <- table(annot$MPC_class1, annot$SIFT, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class2, annot$SIFT, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class1, annot$PolyPhen, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$MPC_class2, annot$PolyPhen, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$CADD_class20, annot$PolyPhen, useNA="always")
tab1
prop.table(tab1, margin = 1)

tab1 <- table(annot$CADD_class20, annot$SIFT, useNA="always")
tab1
prop.table(tab1, margin = 1)

# output data
annot_merge <- annot[,-c("variant_id","CHROM","POS","REF","ALT")]
output_raw <- merge(carrier,annot_merge,by="vcf_variant_id",all.x=TRUE)

output <- output_raw[output_raw$type %like% "missense_variant", ]
summary(factor(output$type))

output_MPC_class2_mpcN <- output[which(is.na(output$MPC_class2)==TRUE),c("gene", "chrom", "pos", "ref", "alt", "min_ref", "min_alt", "variant_id", "vcf_variant_id", "rsid", "type", "aa", "hgvsc", "alt_af", "carriers", "missing")]

output_MPC_class2_mpc0 <- output[which(output$MPC_class2=="mpc0"),c("gene", "chrom", "pos", "ref", "alt", "min_ref", "min_alt", "variant_id", "vcf_variant_id", "rsid", "type", "aa", "hgvsc", "alt_af", "carriers", "missing")]

fwrite(output_MPC_class2_mpcN, paste0("/MYPATH/chr",chrom,"_MPC2_N_carriers.txt.gz"), na="NA", quote=FALSE,sep=" ", compress="gzip")
fwrite(output_MPC_class2_mpc0, paste0("/MYPATH/chr",chrom,"_MPC2_0_carriers.txt.gz"), na="NA", quote=FALSE,sep=" ", compress="gzip")
