#===========================================================
# Educational attainment
#===========================================================
# plot
library(data.table)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(ggpubr)

#---------------------------------------
# Compare p-values from studies
#---------------------------------------
edu <- fread("edu_baseline_irnt.ptv.maf00001.regenie.qc.txt")
fiall <- fread("fiall_baseline_irnt.ptv.maf00001.regenie.qc.txt")
dd <- fread("41586_2020_2832_MOESM4_ESM.DDgene_exome_sumstat.csv")
asd <- fread("ASD_exome_gene_pvalue.plot.csv")

annot_table_raw <- read.table("/MYPATH/gnomad.v2.1.1.lof_metrics.by_gene.txt.bgz",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table <- annot_table_raw[,c("gene","pLI")]
annot_table$pLI <- as.numeric(annot_table$pLI)

ddg2p.file <- read.csv("DDG2P_23_12_2020.csv",stringsAsFactors=FALSE)
ddg2p_highconf <- ddg2p.file$gene.symbol[which(ddg2p.file$DDD.category=="confirmed" | ddg2p.file$DDD.category=="probable")]
ddg2p_all <- ddg2p.file$gene.symbol

asd_sig_list <- c("CHD8", "SCN2A", "SYNGAP1", "ADNP", "FOXP1", "POGZ", "ARID1B", "SUV420H1", "DYRK1A", "SLC6A1", "GRIN2B", "PTEN", "SHANK3", "MED13L", "GIGYF1", "CHD2", "ANKRD11", "ANK2", "ASH1L", "TLK2", "DNMT3A", "DEAF1", "CTNNB1", "KDM6B", "DSCAM", "SETD5", "KCNQ3", "SRPR", "KDM5B", "WAC", "SHANK2", "NRXN1", "TBL1XR1", "MYT1L", "BCL11A", "RORB", "RAI1", "DYNC1H1", "DPYSL2", "AP2S1", "KMT2C", "PAX5", "MKX", "GABRB3", "SIN3A", "MBD5", "MAP1A", "STXBP1", "CELF4", "PHF12", "TBR1", "PPP2R5D", "TM9SF4", "PHF21A", "PRR12", "SKI", "ASXL3", "SPAST", "SMARCC2", "TRIP12", "CREBBP", "TCF4", "CACNA1E", "GNAI1", "TCF20", "FOXP2", "NSD1", "TCF7L2", "LDB1", "EIF3G", "PHF2", "KIAA0232", "VEZF1", "GFAP", "IRF2BPL", "ZMYND8", "SATB1", "RFX3", "SCN1A", "PPP5C", "TRIM23", "TRAF7", "ELAVL3", "GRIA2", "LRRC4C", "CACNA2D3", "NUP155", "KMT2E", "NR3C2", "NACC1", "PTK7", "PPP1R9B", "GABRB2", "HDLBP", "TAOK1", "UBR1", "TEK", "KCNMA1", "CORO1A", "HECTD4", "NCOA1", "DIP2A")

edu_dd <- merge(edu,dd,by.x="GENE",by.y="symbol",all=TRUE)
head(edu_dd)
summary(edu_dd)

edu_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "SLC8A1", "BCAS3")
vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A")
eduvnr_gene_list <- unique(c(edu_gene_list, vnr_gene_list))

edu_dd$sigset <- "NO"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list)] <- "EDU"
edu_dd$sigset[which(edu_dd$GENE %in% ddg2p_highconf)] <- "DDG2P"
edu_dd$sigset[which(edu_dd$GENE %in% asd_sig_list)] <- "ASD"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% ddg2p_highconf)] <- "DDG2P & EDU"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% asd_sig_list)] <- "EDU & ASD"
edu_dd$sigset[which(edu_dd$GENE %in% asd_sig_list & edu_dd$GENE %in% ddg2p_highconf)] <- "ASD & DDG2P"
edu_dd$sigset[which(edu_dd$GENE %in% edu_gene_list & edu_dd$GENE %in% asd_sig_list & edu_dd$GENE %in% ddg2p_highconf)] <- "EDU & DDG2P & ASD"
edu_dd$sigset <- factor(edu_dd$sigset, levels=c("ASD","ASD & DDG2P","DDG2P","DDG2P & EDU","EDU & ASD","EDU","EDU & DDG2P & ASD"))

edu_dd$sig_all <- "NO"
edu_dd[edu_dd$sigset!="NO","sig_all"] <- "YES"

edu_dd_pli <- merge(edu_dd, annot_table, by.x="GENE", by.y="gene", all=TRUE)
edu_dd_pli.sig <- edu_dd_pli[which(edu_dd_pli$sig_all == "YES"),]
table(edu_dd_pli$sigset)
summary(factor(edu_dd_pli$sig_all))
edu_dd_pli.plot <- edu_dd_pli[which(edu_dd_pli$sig_all == "YES"), c("GENE", "pLI", "denovoWEST_p_full","PTV_enrichment_p", "BETA", "SE", "P", "NSAMPLE", "NPTV", "NCARRIER", "sigset", "sig_all")]
edu_dd_pli.plot[which(edu_dd_pli.plot$PTV_enrichment_p==0),"PTV_enrichment_p"] <- 10^-18

#---------------------------------------
# output table
#---------------------------------------
fwrite(edu_dd_pli.plot,"edu_dd_gene_pvalue.ddg2p.csv")

#===========================================================
# Verbal-numerical reasoning
#===========================================================
#---------------------------------------
# Compare p-values from studies
#---------------------------------------
vnr_dd <- merge(fiall,dd,by.x="GENE",by.y="symbol",all=TRUE)
head(vnr_dd)
summary(vnr_dd)

edu_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "SLC8A1", "BCAS3")
vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A")
eduvnr_gene_list <- unique(c(edu_gene_list, vnr_gene_list))

vnr_dd$sigset <- "NO"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list)] <- "VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% ddg2p_highconf)] <- "DDG2P"
vnr_dd$sigset[which(vnr_dd$GENE %in% asd_sig_list)] <- "ASD"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "DDG2P & VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% asd_sig_list)] <- "ASD & VNR"
vnr_dd$sigset[which(vnr_dd$GENE %in% asd_sig_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "ASD & DDG2P"
vnr_dd$sigset[which(vnr_dd$GENE %in% vnr_gene_list & vnr_dd$GENE %in% asd_sig_list & vnr_dd$GENE %in% ddg2p_highconf)] <- "VNR & DDG2P & ASD"
vnr_dd$sig_all <- "NO"
vnr_dd[vnr_dd$sigset!="NO","sig_all"] <- "YES"

vnr_dd$sig_all <- "NO"
vnr_dd[vnr_dd$sigset!="NO","sig_all"] <- "YES"

vnr_dd_pli <- merge(vnr_dd, annot_table, by.x="GENE", by.y="gene", all=TRUE)
vnr_dd_pli.sig <- vnr_dd_pli[which(vnr_dd_pli$sig_all == "YES"),]
table(vnr_dd_pli$sigset)
summary(factor(vnr_dd_pli$sig_all))
vnr_dd_pli.plot <- vnr_dd_pli[which(vnr_dd_pli$sig_all == "YES"), c("GENE", "pLI", "denovoWEST_p_full","PTV_enrichment_p", "BETA", "SE", "P", "NSAMPLE", "NPTV", "NCARRIER", "sigset", "sig_all")]
vnr_dd_pli.plot[which(vnr_dd_pli.plot$PTV_enrichment_p==0),"PTV_enrichment_p"] <- 10^-18

#---------------------------------------
# output table
#---------------------------------------
fwrite(vnr_dd_pli.plot,"vnr_dd_gene_pvalue.ddg2p.csv")

#---------------------------------------
# make table
#---------------------------------------
edu <- fread("edu_baseline_irnt.ptv.maf00001.regenie.qc.txt")
fiall <- fread("fiall_baseline_irnt.ptv.maf00001.regenie.qc.txt")
rt <- fread("rt_baseline_irnt.ptv.maf00001.regenie.qc.txt")
dd <- fread("41586_2020_2832_MOESM4_ESM.DDgene_exome_sumstat.csv")
asd[which(asd$gene=="BAI2"),"gene"] <- "ADGRB2"

annot_table_raw <- read.table("/MYPATH/gnomad.v2.1.1.lof_metrics.by_gene.txt.bgz",header=TRUE,stringsAsFactors=FALSE,sep="\t")
annot_table <- annot_table_raw[,c("gene","pLI")]
annot_table$pLI <- as.numeric(annot_table$pLI)

asd_sig_list <- c("CHD8", "SCN2A", "SYNGAP1", "ADNP", "FOXP1", "POGZ", "ARID1B", "SUV420H1", "DYRK1A", "SLC6A1", "GRIN2B", "PTEN", "SHANK3", "MED13L", "GIGYF1", "CHD2", "ANKRD11", "ANK2", "ASH1L", "TLK2", "DNMT3A", "DEAF1", "CTNNB1", "KDM6B", "DSCAM", "SETD5", "KCNQ3", "SRPR", "KDM5B", "WAC", "SHANK2", "NRXN1", "TBL1XR1", "MYT1L", "BCL11A", "RORB", "RAI1", "DYNC1H1", "DPYSL2", "AP2S1", "KMT2C", "PAX5", "MKX", "GABRB3", "SIN3A", "MBD5", "MAP1A", "STXBP1", "CELF4", "PHF12", "TBR1", "PPP2R5D", "TM9SF4", "PHF21A", "PRR12", "SKI", "ASXL3", "SPAST", "SMARCC2", "TRIP12", "CREBBP", "TCF4", "CACNA1E", "GNAI1", "TCF20", "FOXP2", "NSD1", "TCF7L2", "LDB1", "EIF3G", "PHF2", "KIAA0232", "VEZF1", "GFAP", "IRF2BPL", "ZMYND8", "SATB1", "RFX3", "SCN1A", "PPP5C", "TRIM23", "TRAF7", "ELAVL3", "GRIA2", "LRRC4C", "CACNA2D3", "NUP155", "KMT2E", "NR3C2", "NACC1", "PTK7", "PPP1R9B", "GABRB2", "HDLBP", "TAOK1", "UBR1", "TEK", "KCNMA1", "CORO1A", "HECTD4", "NCOA1", "DIP2A")
edu_gene_list <- c("ADGRB2", "KDM5B", "GIGYF1", "SLC8A1", "BCAS3")
vnr_gene_list <- c("KDM5B", "ANKRD12", "RC3H2", "CACNA1A")
eduvnr_gene_list <- unique(c(edu_gene_list, vnr_gene_list))
ddg2p.file <- read.csv("DDG2P_23_12_2020.csv",stringsAsFactors=FALSE)
ddg2p_highconf <- ddg2p.file$gene.symbol[which(ddg2p.file$DDD.category=="confirmed" | ddg2p.file$DDD.category=="probable")]
ddg2p_all <- ddg2p.file$gene.symbol

edu_dd <- merge(edu,dd,by.x="GENE",by.y="symbol",all=TRUE)
edu_dd <- edu_dd[,c("GENE", "BETA", "SE", "P", "NSAMPLE", "NPTV", "NCARRIER", "PTV_enrichment_p", "denovoWEST_p_full", "significant")]
fiall_edu_dd <- merge(fiall,edu_dd,by="GENE",all=TRUE)
fiall_edu_dd_pli <- merge(fiall_edu_dd, annot_table, by.x="GENE", by.y="gene", all=TRUE)

fiall_edu_dd_pli$EDU_sig <- "NO"
fiall_edu_dd_pli$EDU_sig[which(fiall_edu_dd_pli$GENE %in% edu_gene_list)] <- "YES"
fiall_edu_dd_pli$VNR_sig <- "NO"
fiall_edu_dd_pli$VNR_sig[which(fiall_edu_dd_pli$GENE %in% vnr_gene_list)] <- "YES"
fiall_edu_dd_pli$ASD_sig <- "NO"
fiall_edu_dd_pli$ASD_sig[which(fiall_edu_dd_pli$GENE %in% asd_sig_list)] <- "YES"
fiall_edu_dd_pli$DeNovoWEST_sig <- "NO"
fiall_edu_dd_pli$DeNovoWEST_sig[which(fiall_edu_dd_pli$significant==TRUE)] <- "YES"
fiall_edu_dd_pli$DDG2P <- "NO"
fiall_edu_dd_pli$DDG2P[which(fiall_edu_dd_pli$GENE %in% ddg2p_highconf)] <- "YES"

output_raw <- fiall_edu_dd_pli[which(fiall_edu_dd_pli$EDU_sig=="YES" | fiall_edu_dd_pli$VNR_sig=="YES" | fiall_edu_dd_pli$ASD_sig=="YES" | fiall_edu_dd_pli$DeNovoWEST_sig=="YES" | fiall_edu_dd_pli$DDG2P=="YES"),]

output_raw$EDU_sig <- factor(output_raw$EDU_sig)
output_raw$VNR_sig <- factor(output_raw$VNR_sig)
output_raw$ASD_sig <- factor(output_raw$ASD_sig)
output_raw$DeNovoWEST_sig <- factor(output_raw$DeNovoWEST_sig)
output_raw$DDG2P <- factor(output_raw$DDG2P)

output <- output_raw[,c("GENE", "BETA.x", "P.x", "BETA.y", "P.y", "PTV_enrichment_p", "denovoWEST_p_full", "pLI", "EDU_sig", "VNR_sig", "ASD_sig", "DeNovoWEST_sig", "DDG2P")]
colnames(output) <- c("GENE", "BETA_EDU", "P_EDU", "BETA_VNR", "P_VNR", "PTV_enrichment_p", "denovoWEST_p_full", "pLI", "EDU_sig", "VNR_sig", "ASD_sig", "DeNovoWEST_sig", "DDG2P")

fwrite(output,"fiall_edu_dd_pli.comparison.csv",na="NA")
